@@ -114,7 +114,7 @@ ms_obj_attr_new_array (MSObjAttrID id, GArray *array)
 }
 
 MSObjAttr *
-ms_obj_attr_new_expr (MSObjAttrID id, GnmExpr const *expr)
+ms_obj_attr_new_expr (MSObjAttrID id, GnmExprTop const *texpr)
 {
 	MSObjAttr *res = g_new (MSObjAttr, 1);
 
@@ -122,7 +122,7 @@ ms_obj_attr_new_expr (MSObjAttrID id, GnmExpr const *expr)
 
 	/* be anal about constness */
 	*((MSObjAttrID *)&(res->id)) = id;
-	res->v.v_expr = expr;
+	res->v.v_texpr = texpr;
 	return res;
 }
 
@@ -140,6 +140,19 @@ ms_obj_attr_new_markup (MSObjAttrID id, PangoAttrList *markup)
 	return res;
 }
 
+MSObjAttr *
+ms_obj_attr_new_gobject (MSObjAttrID id, GObject *object)
+{
+	MSObjAttr *res = g_new (MSObjAttr, 1);
+
+	g_return_val_if_fail ((id & MS_OBJ_ATTR_MASK) == MS_OBJ_ATTR_IS_GOBJECT_MASK, NULL);
+
+	*((MSObjAttrID *)&(res->id)) = id;
+	res->v.v_object = object;
+	g_object_ref (object);
+	return res;
+}
+
 guint32
 ms_obj_attr_get_uint (MSObjAttrBag *attrs, MSObjAttrID id, guint32 default_value)
 {
@@ -206,12 +219,12 @@ ms_obj_attr_get_array (MSObjAttrBag *attrs, MSObjAttrID id,
 	return res;
 }
 
-GnmExpr const *
+GnmExprTop const *
 ms_obj_attr_get_expr (MSObjAttrBag *attrs, MSObjAttrID id,
-		      GnmExpr const *default_value, gboolean steal)
+		      GnmExprTop const *default_value, gboolean steal)
 {
 	MSObjAttr *attr;
-	GnmExpr const *res;
+	GnmExprTop const *res;
 
 	g_return_val_if_fail (attrs != NULL, default_value);
 	g_return_val_if_fail (id & MS_OBJ_ATTR_IS_EXPR_MASK, default_value);
@@ -219,9 +232,9 @@ ms_obj_attr_get_expr (MSObjAttrBag *attrs, MSObjAttrID id,
 	attr = ms_obj_attr_bag_lookup (attrs, id);
 	if (attr == NULL)
 		return default_value;
-	res = attr->v.v_expr;
+	res = attr->v.v_texpr;
 	if (steal)
-		attr->v.v_expr = NULL;
+		attr->v.v_texpr = NULL;
 	return res;
 }
 
@@ -244,6 +257,20 @@ ms_obj_attr_get_markup (MSObjAttrBag *attrs, MSObjAttrID id,
 	return res;
 }
 
+GObject *
+ms_obj_attr_get_gobject (MSObjAttrBag *attrs, MSObjAttrID id)
+{
+	MSObjAttr *attr;
+
+	g_return_val_if_fail (attrs != NULL, NULL);
+	g_return_val_if_fail (id & MS_OBJ_ATTR_IS_GOBJECT_MASK, NULL);
+
+	attr = ms_obj_attr_bag_lookup (attrs, id);
+	if (attr == NULL)
+		return NULL;
+	return attr->v.v_object;
+}
+
 static void
 ms_obj_attr_destroy (MSObjAttr *attr)
 {
@@ -257,13 +284,17 @@ ms_obj_attr_destroy (MSObjAttr *attr)
 			g_array_free (attr->v.v_array, TRUE);
 			attr->v.v_array = NULL;
 		} else if ((attr->id & MS_OBJ_ATTR_IS_EXPR_MASK) &&
-			   attr->v.v_expr != NULL) {
-			gnm_expr_unref (attr->v.v_expr);
-			attr->v.v_expr = NULL;
+			   attr->v.v_texpr != NULL) {
+			gnm_expr_top_unref (attr->v.v_texpr);
+			attr->v.v_texpr = NULL;
 		} else if ((attr->id & MS_OBJ_ATTR_IS_PANGO_ATTR_LIST_MASK) &&
 			   attr->v.v_markup != NULL) {
 			pango_attr_list_unref (attr->v.v_markup);
 			attr->v.v_markup = NULL;
+		} else if ((attr->id & MS_OBJ_ATTR_IS_GOBJECT_MASK) &&
+			   attr->v.v_object != NULL) {
+			g_object_unref (attr->v.v_object);
+			attr->v.v_object = NULL;
 		}
 		g_free (attr);
 	}
@@ -381,6 +412,8 @@ ms_read_TXO (BiffQuery *q, MSContainer *c, PangoAttrList **markup)
 	int const valign = (options >> 4) & 0x7;
 	char         *text;
 	guint16       op;
+	GString *accum;
+	gboolean continue_seen = FALSE;
 
 	*markup = NULL;
 	if (text_len == 0)
@@ -390,40 +423,34 @@ ms_read_TXO (BiffQuery *q, MSContainer *c, PangoAttrList **markup)
 	g_return_val_if_fail (1 <= halign && halign <= 4, NULL);
 	g_return_val_if_fail (1 <= valign && valign <= 4, NULL);
 
-	if (ms_biff_query_peek_next (q, &op) && op == BIFF_CONTINUE) {
+	accum = g_string_new ("");
+	while (ms_biff_query_peek_next (q, &op) && op == BIFF_CONTINUE) {
 		gboolean use_utf16;
+		guint maxlen;
 
+		continue_seen = TRUE;
 		ms_biff_query_next (q);
 
 		use_utf16 = q->data[0] != 0;
+		maxlen = use_utf16 ? q->length / 2 : q->length-1;
 		text = excel_get_chars (c->importer,
-			q->data + 1, MIN (text_len, q->length-1), use_utf16);
-		if (q->length < text_len) {
-			GString *accum = g_string_new (text);
-			g_free (text);
-			text_len -= q->length - 1;
-			while (ms_biff_query_peek_next (q, &op) && op == BIFF_CONTINUE) {
-				ms_biff_query_next (q);
-				text = excel_get_chars (c->importer, q->data,
-					MIN (q->length, text_len), use_utf16);
-				g_string_append (accum, text);
-				g_free (text);
-				if (text_len <= q->length)
-					break;
-				text_len -= q->length;
-			}
-			text = g_string_free (accum, FALSE);
-		}
-
+			q->data + 1, MIN (text_len, maxlen), use_utf16);
+		g_string_append (accum, text);
+		g_free (text);
+		if (text_len <= maxlen)
+			break;
+		text_len -= maxlen;
+	}
+	text = g_string_free (accum, FALSE);
+	if (continue_seen) {
 		if (ms_biff_query_peek_next (q, &op) && op == BIFF_CONTINUE) {
 			ms_biff_query_next (q);
 			*markup = ms_container_read_markup (c, q->data, q->length, text);
-		} else
+		} else {
 			g_warning ("Unusual, TXO text with no formatting has 0x%x @ 0x%x", op, q->streamPos);
+		}
 	} else {
-		if (text_len > 0)
-			g_warning ("TXO len of %d but no continue", text_len);
-		text = g_strdup ("");
+		g_warning ("TXO len of %d but no continue", text_len);
 	}
 
 #ifndef NO_DEBUG_EXCEL
@@ -549,7 +576,7 @@ read_pre_biff8_read_expr (BiffQuery *q, MSContainer *c, MSObj *obj,
 {
 	guint8 const *ptr  = *first;
 	guint8 const *last = q->data + q->length;
-	GnmExpr const *ref;
+	GnmExprTop const *ref;
 	unsigned len;
 
 	if (total_len <= 0)
@@ -777,7 +804,7 @@ ms_obj_read_pre_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 				GSF_LE_GET_GUINT16 (q->data+56)));
 
 		{
-			GnmExpr const *ref;
+			GnmExprTop const *ref;
 			guint16 len;
 			guint8 const *last = q->data + q->length;
 			guint8 const *ptr = q->data + 64;
@@ -820,8 +847,13 @@ ms_obj_read_pre_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 
 			ms_biff_query_next (q);
 			pixbuf = excel_read_IMDATA (q, FALSE);
-			if (pixbuf)
+			if (pixbuf) {
+			        ms_obj_attr_bag_insert (obj->attrs,
+				        ms_obj_attr_new_gobject 
+						(MS_OBJ_ATTR_IMDATA, 
+						 G_OBJECT (pixbuf)));
 				g_object_unref (pixbuf);
+			}
 		}
 	}
 	return FALSE;
@@ -851,6 +883,9 @@ ms_obj_map_forms_obj (MSObj *obj, MSContainer *c, guint8 const *data, gint32 len
 	int i = G_N_ELEMENTS (map_forms);
 	char const *key;
 	int key_len = 0;
+	guint8 const *ptr;
+	guint16 expr_len;
+	GnmExprTop const *ref;
 
 	if (obj->excel_type != 8 || len <= 27 ||
 	    strncmp ((char *)(data+21), "Forms.", 6))
@@ -865,21 +900,25 @@ ms_obj_map_forms_obj (MSObj *obj, MSContainer *c, guint8 const *data, gint32 len
 			break;
 	}
 
-	if (i >= 0) {
-		obj->excel_type = map_forms [i].excel_type;
-		if (map_forms [i].offset_to_link != 0) {
-			guint8 const *ptr = data + 27 + key_len + map_forms [i].offset_to_link;
-			guint16 expr_len;
-			GnmExpr const *ref;
-			g_return_if_fail (ptr + 2 <= (data + len));
-			expr_len = GSF_LE_GET_GUINT16 (ptr);
-			g_return_if_fail (ptr + 2 + expr_len <= (data + len));
-			ref = ms_container_parse_expr (c, ptr + 6, expr_len);
-			if (ref != NULL)
-				ms_obj_attr_bag_insert (obj->attrs,
-					ms_obj_attr_new_expr (MS_OBJ_ATTR_LINKED_TO_CELL, ref));
-		}
-	}
+	if (i < 0)
+		return;
+	obj->excel_type = map_forms [i].excel_type;
+
+	if (map_forms [i].offset_to_link == 0)
+		return;
+
+	ptr = data + 27 + key_len + map_forms [i].offset_to_link;
+	if (ptr + 2 > (data + len))
+		return;
+
+	expr_len = GSF_LE_GET_GUINT16 (ptr);
+
+	g_return_if_fail (ptr + 2 + expr_len <= (data + len));
+
+	ref = ms_container_parse_expr (c, ptr + 6, expr_len);
+	if (ref != NULL)
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_expr (MS_OBJ_ATTR_LINKED_TO_CELL, ref));
 }
 
 static gboolean
@@ -997,7 +1036,7 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 
 		case GR_SCROLLBAR_FORMULA : {
 			guint16 const expr_len = GSF_LE_GET_GUINT16 (data+4);
-			GnmExpr const *ref = ms_container_parse_expr (c, data+10, expr_len);
+			GnmExprTop const *ref = ms_container_parse_expr (c, data+10, expr_len);
 			if (ref != NULL)
 				ms_obj_attr_bag_insert (obj->attrs,
 					ms_obj_attr_new_expr (MS_OBJ_ATTR_LINKED_TO_CELL, ref));
@@ -1035,7 +1074,7 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 
 		case GR_CHECKBOX_FORMULA : {
 			guint16 const expr_len = GSF_LE_GET_GUINT16 (data+4);
-			GnmExpr const *ref = ms_container_parse_expr (c, data+10, expr_len);
+			GnmExprTop const *ref = ms_container_parse_expr (c, data+10, expr_len);
 			if (ref != NULL)
 				ms_obj_attr_bag_insert (obj->attrs,
 					ms_obj_attr_new_expr (MS_OBJ_ATTR_LINKED_TO_CELL, ref));
@@ -1230,15 +1269,13 @@ ms_read_OBJ (BiffQuery *q, MSContainer *c, MSObjAttrBag *attrs)
 		obj->gnum_obj = (*c->vtbl->create_obj) (c, obj);
 
 	/* Chart, There should be a BOF next */
-	if (obj->excel_type == 0x5 &&
-	    ms_excel_chart_read_BOF (q, c, obj->gnum_obj)) {
-		ms_obj_delete (obj);
-		return;
+	if (obj->excel_type == 0x5) {
+		if (ms_excel_chart_read_BOF (q, c, obj->gnum_obj)) {
+			ms_obj_delete (obj);
+			return;
+		}
 	}
 
-#if 0
-	g_warning ("registered obj %d\n", obj->id);
-#endif
 	ms_container_add_obj (c, obj);
 }
 
@@ -1297,8 +1334,3 @@ ms_objv8_write_listbox (BiffPut *bp, gboolean filtered)
 		GSF_LE_SET_GUINT16 (buf + 14, 0xa);
 	ms_biff_put_var_write (bp, buf, sizeof data);
 }
-
-void
-ms_objv8_write_chart (BiffPut *bp, SheetObject *sog)
-{
-}
