@@ -119,7 +119,7 @@ static GnmFuncHelp const help_date[] = {
 };
 
 static GnmValue *
-gnumeric_date (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_date (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float year  = value_get_as_float (argv [0]);
 	gnm_float month = value_get_as_float (argv [1]);
@@ -193,7 +193,7 @@ static GnmFuncHelp const help_unix2date[] = {
 };
 
 static GnmValue *
-gnumeric_unix2date (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_unix2date (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float futime = value_get_as_float (argv [0]);
 	time_t     utime  = (time_t)futime;
@@ -229,7 +229,7 @@ static GnmFuncHelp const help_date2unix[] = {
 };
 
 static GnmValue *
-gnumeric_date2unix (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_date2unix (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float fserial = value_get_as_float (argv [0]);
 	int        serial  = (int)fserial;
@@ -266,7 +266,7 @@ static GnmFuncHelp const help_datevalue[] = {
 };
 
 static GnmValue *
-gnumeric_datevalue (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_datevalue (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return value_new_int (datetime_value_to_serial (argv[0], DATE_CONV (ei->pos)));
 }
@@ -388,7 +388,7 @@ datedif_opt_md (GDate *gdate1, GDate *gdate2, gboolean excel_compat)
 }
 
 static GnmValue *
-gnumeric_datedif (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_datedif (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int date1, date2;
 	char const *opt;
@@ -449,7 +449,7 @@ static GnmFuncHelp const help_edate[] = {
 };
 
 static GnmValue *
-gnumeric_edate (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_edate (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GODateConventions const *conv = DATE_CONV (ei->pos);
 	gnm_float serial = value_get_as_float (argv[0]);
@@ -499,7 +499,7 @@ static GnmFuncHelp const help_today[] = {
 };
 
 static GnmValue *
-gnumeric_today (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_today (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return make_date (value_new_int (datetime_timet_to_serial (time (NULL), DATE_CONV (ei->pos))));
 }
@@ -533,7 +533,7 @@ static GnmFuncHelp const help_now[] = {
 };
 
 static GnmValue *
-gnumeric_now (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_now (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return value_new_float (datetime_timet_to_serial_raw (time (NULL), DATE_CONV (ei->pos)));
 }
@@ -558,7 +558,7 @@ static GnmFuncHelp const help_time[] = {
 };
 
 static GnmValue *
-gnumeric_time (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_time (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float hours, minutes, seconds;
 
@@ -592,7 +592,7 @@ static GnmFuncHelp const help_timevalue[] = {
 };
 
 static GnmValue *
-gnumeric_timevalue (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_timevalue (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float raw = datetime_value_to_serial_raw (argv[0], DATE_CONV (ei->pos));
 	return value_new_float (raw - (int)raw);
@@ -623,7 +623,7 @@ static GnmFuncHelp const help_hour[] = {
 };
 
 static GnmValue *
-gnumeric_hour (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_hour (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float d = value_get_as_float (argv[0]);
 
@@ -660,7 +660,7 @@ static GnmFuncHelp const help_minute[] = {
 };
 
 static GnmValue *
-gnumeric_minute (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_minute (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float d = value_get_as_float (argv[0]);
 
@@ -697,7 +697,7 @@ static GnmFuncHelp const help_second[] = {
 };
 
 static GnmValue *
-gnumeric_second (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_second (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float d = value_get_as_float (argv[0]);
 
@@ -733,7 +733,7 @@ static GnmFuncHelp const help_year[] = {
 };
 
 static GnmValue *
-gnumeric_year (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_year (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int res = 1900;
 	GDate date;
@@ -767,7 +767,7 @@ static GnmFuncHelp const help_month[] = {
 };
 
 static GnmValue *
-gnumeric_month (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_month (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int res = 1;
 	GDate date;
@@ -801,7 +801,7 @@ static GnmFuncHelp const help_day[] = {
 };
 
 static GnmValue *
-gnumeric_day (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_day (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int res = 1;
 	GDate date;
@@ -842,7 +842,7 @@ static GnmFuncHelp const help_weekday[] = {
 };
 
 static GnmValue *
-gnumeric_weekday (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_weekday (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	int res;
@@ -901,7 +901,7 @@ static GnmFuncHelp const help_days360[] = {
 };
 
 static GnmValue *
-gnumeric_days360 (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_days360 (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	basis_t basis;
 	GDate date1, date2;
@@ -946,7 +946,7 @@ static GnmFuncHelp const help_eomonth[] = {
 };
 
 static GnmValue *
-gnumeric_eomonth (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_eomonth (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float months = argv[1] ? value_get_as_float (argv[1]) : 0;
 	GDate date;
@@ -1012,7 +1012,7 @@ float_compare (gnm_float const *a, gnm_float const *b)
 }
 
 static GnmValue *
-gnumeric_workday (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_workday (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	GODateConventions const *conv = DATE_CONV (ei->pos);
@@ -1230,7 +1230,7 @@ networkdays_holiday_callback (GnmValue const *v, GnmEvalPos const *ep,
 }
 
 static GnmValue *
-gnumeric_networkdays (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_networkdays (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int start_serial;
 	int end_serial;
@@ -1304,7 +1304,7 @@ static GnmFuncHelp const help_isoweeknum[] = {
 };
 
 static GnmValue *
-gnumeric_isoweeknum (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_isoweeknum (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	datetime_value_to_g (&date, argv[0], DATE_CONV (ei->pos));
@@ -1342,7 +1342,7 @@ static GnmFuncHelp const help_isoyear[] = {
 };
 
 static GnmValue *
-gnumeric_isoyear (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_isoyear (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	int year;
@@ -1395,7 +1395,7 @@ static GnmFuncHelp const help_weeknum[] = {
 };
 
 static GnmValue *
-gnumeric_weeknum (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_weeknum (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	gnm_float method = argv[1] ? gnm_floor (value_get_as_float (argv[1])) : 1;
@@ -1431,7 +1431,7 @@ static GnmFuncHelp const help_yearfrac[] = {
 };
 
 static GnmValue *
-gnumeric_yearfrac (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_yearfrac (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GODateConventions const *conv = DATE_CONV (ei->pos);
 	GDate start_date, end_date;
