@@ -26,6 +26,7 @@
 
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-utils.h>
+#include <gsf/gsf-msole-utils.h>
 #include <string.h>
 
 #define LOTUS_DEBUG 0
@@ -271,6 +272,9 @@ static const guint16 lmbcs_group_f[256] = {
 	0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000
 };
 
+static guint16 lmbcs_group_12[128][256];
+static GIConv lmbcs_12_iconv;
+
 /* ------------------------------------------------------------------------- */
 
 static const guint8
@@ -644,15 +648,15 @@ lotus_pattern (guint i)
 
 /* ------------------------------------------------------------------------- */
 
-static const char *const
+static char const * const
 lotus_special_formats[16] = {
 	"",
-	"",
+	"General",
 	"d-mmm-yy",
 	"d-mmm",
 	"mmm yy",
 	"",
-	"",
+	";;;",  /* Hidden */
 	"h:mm:ss AM/PM",			/* Need am/pm */
 	"h:mm",
 	"m/d/yy",
@@ -667,7 +671,7 @@ lotus_special_formats[16] = {
 static void
 append_precision (GString *res, guint n)
 {
-	static const char dotzeros[17] = ".0000000000000000";
+	static char const dotzeros[17] = ".0000000000000000";
 	if (n > 0)
 		g_string_append_len (res, dotzeros, n + 1);
 }
@@ -716,10 +720,14 @@ lotus_format_string (guint fmt)
 		g_warning ("Country format used.");
 		break;
 
-	case 7:
+	case 7: {
 		/* Lotus special format */
-		g_string_append (res, lotus_special_formats[precision]);
+		char const *f = lotus_special_formats[precision];
+		if (f[0] == 0)
+			f = "General";
+		g_string_append (res, f);
 		break;
+	}
 
 	default:
 		g_warning ("Unknown format type %d used.", fmt_type);
@@ -735,7 +743,7 @@ cell_set_format_from_lotus_format (GnmCell *cell, guint fmt)
 {
 	char *fmt_string = lotus_format_string (fmt);
 	if (fmt_string[0])
-		cell_set_format (cell, fmt_string);
+		gnm_cell_set_format (cell, fmt_string);
 #ifdef DEBUG_FORMAT
 	g_print ("Format: %s\n", fmt_string);
 #endif
@@ -1306,6 +1314,9 @@ lotus_set_formats_cb (LotusState *state, const GnmSheetRange *r,
 	}
 
 	fmt_string = lotus_format_string (fmt);
+#ifdef DEBUG_FORMAT
+	g_print ("Format 0x%x: %s\n", fmt, fmt_string);
+#endif
 	gnm_style_set_format_text (style, fmt_string);
 	g_free (fmt_string);
 	sheet_apply_style (r->sheet, &r->range, style);
@@ -1452,7 +1463,7 @@ insert_value (Sheet *sheet, guint32 col, guint32 row, GnmValue *val)
 
 	cell = sheet_cell_fetch (sheet, col, row);
 
-	cell_set_value (cell, val);
+	gnm_cell_set_value (cell, val);
 
 #if LOTUS_DEBUG > 0
 	printf ("Inserting value at %s:\n",
@@ -1526,7 +1537,7 @@ lotus_read_old (LotusState *state, record_t *r)
 		case LOTUS_LABEL: CHECK_RECORD_SIZE (>= 7) {
 			/* one of '\', '''', '"', '^' */
 /*			gchar format_prefix = *(r->data + 1 + 4);*/
-			GnmValue *v = lotus_new_string (r->data + 6);
+			GnmValue *v = lotus_new_string (r->data + 6, state->lmbcs_group);
 			guint8 fmt = GSF_LE_GET_GUINT8 (r->data);
 			int i = GSF_LE_GET_GUINT16 (r->data + 1);
 			int j = GSF_LE_GET_GUINT16 (r->data + 3);
@@ -1542,7 +1553,7 @@ lotus_read_old (LotusState *state, record_t *r)
 			int col = GSF_LE_GET_GUINT16 (r->data + 1);
 			int row = GSF_LE_GET_GUINT16 (r->data + 3);
 			int len = GSF_LE_GET_GINT16 (r->data + 13);
-			GnmExpr const *expr;
+			GnmExprTop const *texpr;
 			GnmParsePos pp;
 			GnmValue *v = NULL;
 
@@ -1553,8 +1564,8 @@ lotus_read_old (LotusState *state, record_t *r)
 			pp.eval.row = row;
 			pp.sheet = state->sheet;
 			pp.wb = pp.sheet->workbook;
-			expr = lotus_parse_formula (state, &pp,
-						    r->data + 15, len);
+			texpr = lotus_parse_formula (state, &pp,
+						     r->data + 15, len);
 
 			if (0x7ff0 == (GSF_LE_GET_GUINT16 (r->data + 11) & 0x7ff8)) {
 				/* I cannot find normative definition
@@ -1564,15 +1575,15 @@ lotus_read_old (LotusState *state, record_t *r)
 				 */
 				if (LOTUS_STRING == record_peek_next (r)) {
 					record_next (r);
-					v = lotus_new_string (r->data + 5);
+					v = lotus_new_string (r->data + 5, state->lmbcs_group);
 				} else
 					v = value_new_error_VALUE (NULL);
 			} else
 				v = lotus_value (gsf_le_get_double (r->data + 5));
 			cell = sheet_cell_fetch (state->sheet, col, row);
-			cell_set_expr_and_value (cell, expr, v, TRUE);
+			gnm_cell_set_expr_and_value (cell, texpr, v, TRUE);
 
-			gnm_expr_unref (expr);
+			gnm_expr_top_unref (texpr);
 			cell_set_format_from_lotus_format (cell, fmt);
 			break;
 		}
@@ -1591,19 +1602,61 @@ lotus_get_sheet (Workbook *wb, int i)
 	g_return_val_if_fail (i >= 0 && i <= 255, NULL);
 
 	while (i >= workbook_sheet_count (wb))
-		workbook_sheet_add (wb, -1, FALSE);
+		workbook_sheet_add (wb, -1);
 
 	return workbook_sheet_by_index (wb, i);
 }
 
+static gunichar
+lmbcs_12 (const guint8 *p)
+{
+	guint8 c0, c1;
+	gunichar uc;
+
+	if ((c0 = p[0]) == 0 || (c1 = p[1]) == 0)
+		return 0;
+
+	/* Might be wrong for 0x80 */
+	if (c0 <= 0x80 || c0 == 0xff)
+		return 0;
+
+	uc = lmbcs_group_12[c0 - 0x80][c1];
+	if (uc == 0) {
+		char *s;
+		gsize bytes_read;
+
+		if (lmbcs_12_iconv == (GIConv)0)
+			lmbcs_12_iconv = gsf_msole_iconv_open_for_import (950);
+		if (lmbcs_12_iconv == (GIConv)-1)
+			return 0;
+
+		s = g_convert_with_iconv ((const gchar *)p, 2,
+					  lmbcs_12_iconv,
+					  &bytes_read, NULL,
+					  NULL);
+		if (s && bytes_read == 2)
+			uc = g_utf8_get_char (s);
+		else
+			uc = 0xffff;
+		g_free (s);
+
+		lmbcs_group_12[c0 - 0x80][c1] = uc;
+	}
+
+	if (uc == 0xffff)
+		return 0;
+	return uc;
+}
+
+
 char *
-lotus_get_lmbcs (const char *data, int maxlen)
+lotus_get_lmbcs (char const *data, int maxlen, int def_group)
 {
 	GString *res = g_string_sized_new (maxlen + 2);
-	const guint8 *p;
-	const guint8 *theend;
+	guint8 const *p;
+	guint8 const *theend;
 
-	p = (const guint8 *)data;
+	p = (guint8 const *)data;
 	if (maxlen == -1)
 		maxlen = strlen (data);
 	theend = p + maxlen;
@@ -1708,7 +1761,7 @@ lotus_get_lmbcs (const char *data, int maxlen)
 			break;
 		}
 
-		case 0x10: case 0x11: case 0x12: case 0x13:
+		case 0x10: case 0x11: case 0x13:
 		case 0x15: case 0x16: case 0x17: {
 			unsigned code = (p[0] << 16) | (p[1] << 8) | p[2];
 			g_warning ("Unhandled character 0x%06x", code);
@@ -1717,6 +1770,14 @@ lotus_get_lmbcs (const char *data, int maxlen)
 			break;
 		}
 
+		case 0x12: {
+			gunichar uc = lmbcs_12 (p + 1);
+			p += 3;
+			if (uc)
+				g_string_append_unichar (res, uc);
+			break;
+		}
+
 		case 0x18: case 0x19: case 0x1a: case 0x1b:
 		case 0x1c: case 0x1d: case 0x1e: case 0x1f:
 			/* Ignore two bytes.  */
@@ -1739,8 +1800,26 @@ lotus_get_lmbcs (const char *data, int maxlen)
 			if (p[0] <= 0x7f) {
 				g_string_append_c (res, *p++);
 			} else {
-				/* Assume default group is 1.  */
-				gunichar uc = lmbcs_group_1[*p++];
+				guint8 c = p[0];
+				gunichar uc = 0;
+
+				switch (def_group) {
+				case 0x01: uc = lmbcs_group_1[c]; p++; break;
+				case 0x02: uc = lmbcs_group_2[c]; p++; break;
+				case 0x03: if (c >= 0x80) uc = lmbcs_group_3[c - 0x80]; p++; break;
+				case 0x04: if (c >= 0x80) uc = lmbcs_group_4[c - 0x80]; p++; break;
+				case 0x05: if (c >= 0x80) uc = lmbcs_group_5[c - 0x80]; p++; break;
+				case 0x06: uc = lmbcs_group_6[c]; p++; break;
+				case 0x08: if (c >= 0x80) uc = lmbcs_group_8[c - 0x80]; p++; break;
+				case 0x0b: if (c >= 0x80) uc = lmbcs_group_b[c - 0x80]; p++; break;
+				case 0x0f: uc = lmbcs_group_f[c]; p++; break;
+				case 0x12: uc = lmbcs_12 (p); p += 2; break;
+				default:
+					g_warning ("Unhandled character set 0x%x", def_group);
+					p++;
+					break;
+				}
+
 				if (uc)
 					g_string_append_unichar (res, uc);
 			}
@@ -1753,19 +1832,19 @@ lotus_get_lmbcs (const char *data, int maxlen)
 
 
 static char *
-lotus_get_cstr (const record_t *r, int ofs)
+lotus_get_cstr (const record_t *r, int ofs, int def_group)
 {
 	if (ofs >= r->len)
 		return NULL;
 	else
-		return lotus_get_lmbcs (r->data + ofs, r->len - ofs);
+		return lotus_get_lmbcs (r->data + ofs, r->len - ofs, def_group);
 }
 
 GnmValue *
-lotus_new_string (gchar const *data)
+lotus_new_string (gchar const *data, int def_group)
 {
 	return value_new_string_nocopy
-		(lotus_get_lmbcs (data, strlen (data)));
+		(lotus_get_lmbcs (data, strlen (data), def_group));
 }
 
 static gboolean
@@ -1788,9 +1867,6 @@ lotus_read_new (LotusState *state, record_t *r)
 		switch (r->type) {
 		case LOTUS_BOF: CHECK_RECORD_SIZE (>= 18) {
 			state->lmbcs_group = GSF_LE_GET_GUINT8 (r->data + 16);
-			if (state->lmbcs_group != 1)
-				g_warning ("Unhandled character set setting (%d)",
-					   state->lmbcs_group);
 			break;
 		}
 
@@ -1821,7 +1897,7 @@ lotus_read_new (LotusState *state, record_t *r)
 			Sheet *sheet = lotus_get_sheet (state->wb, r->data[2]);
 			int col = r->data[3];
 /*			gchar format_prefix = *(r->data + ofs + 4);*/
-			GnmValue *v = lotus_new_string (r->data + 5);
+			GnmValue *v = lotus_new_string (r->data + 5, state->lmbcs_group);
 			(void)insert_value (sheet, col, row, v);
 			break;
 		}
@@ -1939,7 +2015,7 @@ lotus_read_new (LotusState *state, record_t *r)
 				guint16 styleid = GSF_LE_GET_GUINT16 (r->data + 2);
 				/* guint8 fontclass = GSF_LE_GET_GUINT8 (r->data + 8); */
 				/* guint8 fontfamily = GSF_LE_GET_GUINT8 (r->data + 9); */
-				char *fontname = lotus_get_cstr (r, 10);
+				char *fontname = lotus_get_cstr (r, 10, state->lmbcs_group);
 
 				if (!fontname) {
 					g_warning ("Invalid fontname record.");
@@ -1987,7 +2063,7 @@ lotus_read_new (LotusState *state, record_t *r)
 
 		case LOTUS_SHEET_NAME: CHECK_RECORD_SIZE (>= 11) {
 			Sheet *sheet = lotus_get_sheet (state->wb, sheetnameno++);
-			char *name = lotus_get_cstr (r, 10);
+			char *name = lotus_get_cstr (r, 10, state->lmbcs_group);
 			g_return_val_if_fail (name != NULL, FALSE);
 			/* Name is followed by something indicating tab colour.  */
 			g_object_set (sheet, "name", name, NULL);
@@ -2008,19 +2084,20 @@ lotus_read_new (LotusState *state, record_t *r)
 			int col = r->data[3];
 			GnmValue *curval = lotus_lnumber (r, 4);
 			GnmParsePos pp;
-			const GnmExpr *expr;
+			const GnmExprTop *texpr;
 			GnmCell *cell;
 
 			pp.eval.col = col;
 			pp.eval.row = row;
 			pp.sheet = sheet;
 			pp.wb = sheet->workbook;
-			expr = lotus_parse_formula (state, &pp,
-						    r->data + 12, r->len - 12);
+			texpr = lotus_parse_formula (state, &pp,
+						     r->data + 12,
+						     r->len - 12);
 			cell = sheet_cell_fetch (sheet, col, row);
-			cell_set_expr_and_value (cell, expr, curval, TRUE);
+			gnm_cell_set_expr_and_value (cell, texpr, curval, TRUE);
 
-			gnm_expr_unref (expr);
+			gnm_expr_top_unref (texpr);
 			break;
 		}
 
@@ -2030,19 +2107,20 @@ lotus_read_new (LotusState *state, record_t *r)
 			int col = r->data[3];
 			GnmValue *curval = lotus_treal (r, 4);
 			GnmParsePos pp;
-			const GnmExpr *expr;
+			const GnmExprTop *texpr;
 			GnmCell *cell;
 
 			pp.eval.col = col;
 			pp.eval.row = row;
 			pp.sheet = sheet;
 			pp.wb = sheet->workbook;
-			expr = lotus_parse_formula (state, &pp,
-						    r->data + 14, r->len - 14);
+			texpr = lotus_parse_formula (state, &pp,
+						     r->data + 14,
+						     r->len - 14);
 			cell = sheet_cell_fetch (sheet, col, row);
-			cell_set_expr_and_value (cell, expr, curval, TRUE);
+			gnm_cell_set_expr_and_value (cell, texpr, curval, TRUE);
 
-			gnm_expr_unref (expr);
+			gnm_expr_top_unref (texpr);
 			break;
 		}
 
@@ -2153,7 +2231,7 @@ lotus_read_new (LotusState *state, record_t *r)
 			int row = GSF_LE_GET_GUINT16 (r->data);
 			Sheet *sheet = lotus_get_sheet (state->wb, r->data[2]);
 			int col = r->data[3];
-			char *text = lotus_get_cstr (r, 5);
+			char *text = lotus_get_cstr (r, 5, state->lmbcs_group);
 			GnmCellPos pos;
 
 			pos.col = col;
@@ -2259,3 +2337,14 @@ lotus_read (LotusState *state)
 
 	return FALSE;
 }
+
+void
+lmbcs_init (void)
+{
+}
+
+void
+lmbcs_shutdown (void)
+{
+	gsf_iconv_close (lmbcs_12_iconv);
+}
