@@ -3,7 +3,7 @@
 /*
  * openoffice-read.c : import open/star calc files
  *
- * Copyright (C) 2002-2005 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  * Copyright (C) 2006 Luciano Miguel Wolf (luciano.wolf@indt.org.br)
  *
  * This program is free software; you can redistribute it and/or
@@ -42,6 +42,7 @@
 #include <style-border.h>
 #include <gnm-format.h>
 #include <command-context.h>
+#include <gutils.h>
 #include <goffice/app/io-context.h>
 #include <goffice/app/go-doc.h>
 #include <goffice/utils/go-units.h>
@@ -54,10 +55,9 @@
 #include <gsf/gsf-opendoc-utils.h>
 #include <gsf/gsf-doc-meta-data.h>
 #include <gsf/gsf-output-stdio.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <string.h>
-#include <locale.h>
 
 #include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-plot-impl.h>
@@ -568,31 +568,51 @@ static char const *
 oo_cellref_parse (GnmCellRef *ref, char const *start, GnmParsePos const *pp)
 {
 	char const *tmp1, *tmp2, *ptr = start;
-	/* sheet name cannot contain '.' a '\'' or a '\"' */
+
 	if (*ptr != '.') {
-		char *name;
-		int offset = 0;
+		char *name, *accum;
 
-		if (*ptr == '$') /* ignore abs vs rel sheet name */
+		/* ignore abs vs rel for sheets */
+		if (*ptr == '$')
 			ptr++;
-		tmp1 = strchr (ptr, '.');
-		if (tmp1 == NULL)
-			return start;
-		if ((*ptr == '\'' || *ptr == '\"') && *ptr == tmp1[-1]) {
-			ptr++;
-			tmp1--;
-			offset = 1;
+
+		/* From the spec :
+		 * 	SheetName   ::= [^\. ']+ | "'" ([^'] | "''")+ "'" */
+		if ('\'' == *ptr) {
+			tmp1 = ++ptr;
+two_quotes :
+			/* missing close paren */
+			if (NULL == (tmp1 = strchr (tmp1, '\'')))
+				return start;
+
+			/* two in a row is the escape for a single */
+			if (tmp1[1] == '\'') {
+				tmp1 += 2;
+				goto two_quotes;
+			}
+
+			/* If a name is quoted the entire named must be quoted */
+			if (tmp1[1] != '.')
+				return start;
+
+			accum = name = g_alloca (tmp1-ptr+1);
+			while (ptr != tmp1)
+				if ('\'' == (*accum++ = *ptr++))
+					ptr++;
+			*accum = '\0';
+			ptr += 2;
+		} else {
+			if (NULL == (tmp1 = strchr (ptr, '.')))
+				return start;
+			name = g_alloca (tmp1-ptr+1);
+			strncpy (name, ptr, tmp1-ptr);
+			name[tmp1-ptr] = '\0';
+			ptr = tmp1 + 1;
 		}
 
-		name = g_alloca (tmp1-ptr+1);
-		strncpy (name, ptr, tmp1-ptr);
-		name[tmp1-ptr] = 0;
-		ptr = tmp1 + 1 + offset;
-
 		/* OpenCalc does not pre-declare its sheets, but it does have a
 		 * nice unambiguous format.  So if we find a name that has not
-		 * been added yet add it.  Reorder below.
-		 */
+		 * been added yet add it.  Reorder below. */
 		ref->sheet = workbook_sheet_by_name (pp->wb, name);
 		if (ref->sheet == NULL) {
 			ref->sheet = sheet_new (pp->wb, name);
@@ -658,7 +678,7 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 	gboolean	 bool_val;
 	gnm_float	 float_val = 0;
 	int array_cols = -1, array_rows = -1;
-	int merge_cols = -1, merge_rows = -1;
+	int merge_cols = 1, merge_rows = 1;
 	GnmStyle *style = NULL;
 	char const *expr_string;
 	GnmRange tmp;
@@ -730,10 +750,14 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 						val = value_new_int (d_serial);
 				}
 			}
-		} else if (gsf_xml_in_namecmp (xin, attrs[0], OO_NS_TABLE, "time-value")) {
+		} else if (gsf_xml_in_namecmp (xin, attrs[0],
+					       (state->ver == OOO_VER_OPENDOC) ? OO_NS_OFFICE : OO_NS_TABLE,
+					       "time-value")) {
 			unsigned h, m, s;
-			if (3 == sscanf (attrs[1], "PT%uH%uM%uS", &h, &m, &s))
-				val = value_new_float (h + ((double)m / 60.) + ((double)s / 3600.));
+			if (3 == sscanf (attrs[1], "PT%uH%uM%uS", &h, &m, &s)) {
+				unsigned secs = h * 3600 + m * 60 + s;
+				val = value_new_float (secs / (gnm_float)86400);
+			}
 		} else if (gsf_xml_in_namecmp (xin, attrs[0], OO_NS_TABLE, "string-value"))
 			val = value_new_string (attrs[1]);
 		else if (oo_attr_float (xin, attrs,
@@ -756,17 +780,12 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 	if (style != NULL) {
 		gnm_style_ref (style);
 		if (state->col_inc > 1 || state->row_inc > 1) {
-			range_init (&tmp,
-				state->pos.eval.col, state->pos.eval.row,
-				state->pos.eval.col + state->col_inc - 1,
-				state->pos.eval.row + state->row_inc - 1);
+			range_init_cellpos_size (&tmp, &state->pos.eval,
+				state->col_inc, state->row_inc);
 			sheet_style_set_range (state->pos.sheet, &tmp, style);
-		} else if (merge_cols > 0 || merge_rows > 0) {
-			GnmRange tmp;
-			range_init (&tmp,
-				state->pos.eval.col, state->pos.eval.row,
-				state->pos.eval.col + merge_cols - 1,
-				state->pos.eval.row + merge_rows - 1);
+		} else if (merge_cols > 1 || merge_rows > 1) {
+			range_init_cellpos_size (&tmp, &state->pos.eval,
+				merge_cols, merge_rows);
 			sheet_style_set_range (state->pos.sheet, &tmp, style);
 		} else
 			sheet_style_set_pos (state->pos.sheet,
@@ -779,26 +798,26 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 			state->pos.eval.col, state->pos.eval.row);
 
 		if (array_cols > 0 || array_rows > 0) {
-			if (array_cols < 0) {
+			if (array_cols <= 0) {
 				array_cols = 1;
 				oo_warning (xin, _("Invalid array expression does not specify number of columns."));
-			} else if (array_rows < 0) {
+			} else if (array_rows <= 0) {
 				array_rows = 1;
 				oo_warning (xin, _("Invalid array expression does not specify number of rows."));
 			}
-			cell_set_array_formula (state->pos.sheet,
+			gnm_cell_set_array_formula (state->pos.sheet,
 				state->pos.eval.col, state->pos.eval.row,
 				state->pos.eval.col + array_cols-1,
 				state->pos.eval.row + array_rows-1,
 				texpr);
 			if (val != NULL)
-				cell_assign_value (cell, val);
+				gnm_cell_assign_value (cell, val);
 		} else {
 			if (val != NULL)
-				cell_set_expr_and_value (cell, texpr, val,
+				gnm_cell_set_expr_and_value (cell, texpr, val,
 							 TRUE);
 			else
-				cell_set_expr (cell, texpr);
+				gnm_cell_set_expr (cell, texpr);
 			gnm_expr_top_unref (texpr);
 		}
 	} else if (val != NULL) {
@@ -806,22 +825,18 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 			state->pos.eval.col, state->pos.eval.row);
 
 		/* has cell previously been initialized as part of an array */
-		if (cell_is_nonsingleton_array (cell))
-			cell_assign_value (cell, val);
+		if (gnm_cell_is_nonsingleton_array (cell))
+			gnm_cell_assign_value (cell, val);
 		else
-			cell_set_value (cell, val);
+			gnm_cell_set_value (cell, val);
 	} else if (!state->error_content)
 		/* store the content as a string */
 		state->simple_content = TRUE;
 
-	if (merge_cols > 0 && merge_rows > 0) {
-		GnmRange r;
-		range_init (&r,
-			state->pos.eval.col, state->pos.eval.row,
-			state->pos.eval.col + merge_cols - 1,
-			state->pos.eval.row + merge_rows - 1);
-		sheet_merge_add (state->pos.sheet, &r, FALSE,
-				 NULL);
+	if (merge_cols > 1 || merge_rows > 1) {
+		range_init_cellpos_size (&tmp, &state->pos.eval,
+			merge_cols, merge_rows);
+		gnm_sheet_merge_add (state->pos.sheet, &tmp, FALSE, NULL);
 	}
 }
 
@@ -834,13 +849,13 @@ oo_cell_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 		GnmCell *cell = sheet_cell_get (state->pos.sheet,
 			state->pos.eval.col, state->pos.eval.row);
 
-		if (!cell_is_empty (cell)) {
+		if (!gnm_cell_is_empty (cell)) {
 			int i = 1;
 			GnmCell *next;
 			for (; i < state->col_inc ; i++) {
 				next = sheet_cell_fetch (state->pos.sheet,
 					state->pos.eval.col + i, state->pos.eval.row);
-				cell_set_value (next, value_dup (cell->value));
+				gnm_cell_set_value (next, value_dup (cell->value));
 			}
 		}
 	}
@@ -892,7 +907,7 @@ oo_cell_content_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 			v = value_new_string (xin->content->str);
 		else
 			v = value_new_error (NULL, xin->content->str);
-		cell_set_value (cell, v);
+		gnm_cell_set_value (cell, v);
 	}
 }
 
@@ -1183,9 +1198,9 @@ oo_parse_border (GsfXMLIn *xin, GnmStyle *style,
 	char *border_color = NULL;
 	char *border_type = NULL;
 	size_t pos = 0;
-	StyleBorderType border_style;
-	StyleBorderLocation const loc =
-		STYLE_BORDER_TOP + (int)(location - MSTYLE_BORDER_TOP);
+	GnmStyleBorderType border_style;
+	GnmStyleBorderLocation const loc =
+		GNM_STYLE_BORDER_TOP + (int)(location - MSTYLE_BORDER_TOP);
 
 	if (end == NULL || end == str)
 		return;
@@ -1202,16 +1217,16 @@ oo_parse_border (GsfXMLIn *xin, GnmStyle *style,
 
 		if (!strcmp("solid", border_type)) {
 			if (pts <= OD_BORDER_THIN)
-				border_style = STYLE_BORDER_THIN;
+				border_style = GNM_STYLE_BORDER_THIN;
 			else if (pts <= OD_BORDER_MEDIUM)
-				border_style = STYLE_BORDER_MEDIUM;
+				border_style = GNM_STYLE_BORDER_MEDIUM;
 			else
-				border_style = STYLE_BORDER_THICK;
+				border_style = GNM_STYLE_BORDER_THICK;
 		} else
-			border_style = STYLE_BORDER_DOUBLE;
+			border_style = GNM_STYLE_BORDER_DOUBLE;
 
-		border = style_border_fetch (border_style, color,
-					     style_border_get_orientation (loc));
+		border = gnm_style_border_fetch (border_style, color,
+					     gnm_style_border_get_orientation (loc));
 		border->width = pts;
 		gnm_style_set_border (style, location, border);
 		free (border_type);
@@ -1551,7 +1566,7 @@ od_draw_frame (GsfXMLIn *xin, xmlChar const **attrs)
 	frame_offset[2] = (width/col->size_pts);
 	frame_offset[3] = (height/row->size_pts);
 
-	sheet_object_anchor_init (&state->cur_frame.anchor, &cell_base, frame_offset, NULL, SO_DIR_DOWN_RIGHT);
+	sheet_object_anchor_init (&state->cur_frame.anchor, &cell_base, frame_offset, NULL, GOD_ANCHOR_DIR_DOWN_RIGHT);
 }
 
 static void
@@ -2304,12 +2319,20 @@ oo_unknown_hander (char const *name,
 		   GnmExprList *args,
 		   GnmExprConventions const *convs)
 {
+	GnmFunc *f;
+
 	if (0 == strncmp ("com.sun.star.sheet.addin.Analysis.get", name, 37)) {
 		GnmFunc *f = gnm_func_lookup (name + 37, NULL);
 		if (f != NULL)
 			return gnm_expr_new_funcall (f, args);
 		g_warning ("unknown function");
-	}
+	} else if (0 == strcmp ("INDIRECT_XL", name))
+		name = "INDIRECT";
+	else if (0 == strcmp ("ADDRESS_XL", name))
+		name = "ADDRESS";
+	f = gnm_func_lookup (name, NULL);
+	if (f != NULL)
+		return gnm_expr_new_funcall (f, args);
 	return gnm_func_placeholder_factory (name, args, convs);
 }
 
@@ -2341,7 +2364,7 @@ oo_conventions (void)
 void
 openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 		      WorkbookView *wb_view, GsfInput *input);
-void
+G_MODULE_EXPORT void
 openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 		      WorkbookView *wb_view, GsfInput *input)
 {
@@ -2351,9 +2374,9 @@ openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 	GsfInput	*mimetype = NULL;
 	GsfDocMetaData	*meta_data;
 	GsfInfile	*zip;
+	GnmLocale	*locale;
 	OOParseState	 state;
 	GError		*err = NULL;
-	char *old_num_locale, *old_monetary_locale;
 	int i;
 
 	zip = gsf_infile_zip_new (input, &err);
@@ -2405,11 +2428,7 @@ openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 		return;
 	}
 
-	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
-	go_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
-	go_setlocale (LC_MONETARY, "C");
-	go_set_untranslated_bools ();
+	locale = gnm_push_C_locale ();
 
 	/* init */
 	state.context	= io_context;
@@ -2440,9 +2459,8 @@ openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 	state.cur_frame.has_legend = FALSE;
 
 	if (state.ver == OOO_VER_OPENDOC) {
-		GsfInput *meta_file =
-			meta_file = gsf_infile_child_by_name (zip, "meta.xml");
-		if (meta_file != NULL) {
+		GsfInput *meta_file = gsf_infile_child_by_name (zip, "meta.xml");
+		if (NULL != meta_file) {
 			meta_data = gsf_doc_meta_data_new ();
 			err = gsf_opendoc_metadata_read (meta_file, meta_data);
 			if (NULL != err) {
@@ -2456,7 +2474,7 @@ openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 		}
 	}
 
-	if (styles != NULL) {
+	if (NULL != styles) {
 		GsfXMLInDoc *doc = gsf_xml_in_doc_new (styles_dtd, gsf_ooo_ns);
 		gsf_xml_in_doc_parse (doc, styles, &state);
 		gsf_xml_in_doc_free (doc);
@@ -2505,9 +2523,5 @@ openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 
 	gnm_expr_conventions_free (state.exprconv);
 
-	/* go_setlocale restores bools to locale translation */
-	go_setlocale (LC_MONETARY, old_monetary_locale);
-	g_free (old_monetary_locale);
-	go_setlocale (LC_NUMERIC, old_num_locale);
-	g_free (old_num_locale);
+	gnm_pop_C_locale (locale);
 }
