@@ -55,9 +55,9 @@
 #include <sheet-filter.h>
 #include <sheet-object-cell-comment.h>
 #include <print-info.h>
-#include <print-info.h>
 #include <parse-util.h>
 #include <tools/scenarios.h>
+#include <gutils.h>
 
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-output.h>
@@ -67,7 +67,6 @@
 #include <gsf/gsf-opendoc-utils.h>
 
 #include <glib/gi18n-lib.h>
-#include <locale.h>
 
 #define MANIFEST "manifest:"
 #define OFFICE	 "office:"
@@ -291,7 +290,7 @@ od_write_cell (GnmOOExport *state, GnmCell *cell, GnmRange const *merge_range, G
 		char *rendered_string;
 		GnmExprArrayCorner const *ac = NULL;
 
-		if (cell_has_expr(cell)
+		if (gnm_cell_has_expr(cell)
 		    && ((NULL != (ac = gnm_expr_top_get_array_corner
 				  (cell->base.texpr)))
 			|| !gnm_expr_top_is_array_elem (cell->base.texpr))) {
@@ -323,7 +322,7 @@ od_write_cell (GnmOOExport *state, GnmCell *cell, GnmRange const *merge_range, G
 
 		}
 		
-		rendered_string = cell_get_rendered_text (cell);
+		rendered_string = gnm_cell_get_rendered_text (cell);
 		
 		switch (cell->value->type) {
 		case VALUE_BOOLEAN:
@@ -380,8 +379,7 @@ od_write_cell (GnmOOExport *state, GnmCell *cell, GnmRange const *merge_range, G
 static void
 cb_sheet_merges_free (gpointer data, gpointer user_data)
 {
-	if (data != NULL)
-		g_free (data);
+	g_free (data);
 }
 
 static void
@@ -439,7 +437,7 @@ oo_write_sheet (GnmOOExport *state, Sheet const *sheet)
 
 			pos.col = col;
 			cc = sheet_get_comment (sheet, &pos);
-			merge_range = sheet_merge_is_corner (sheet, &pos);
+			merge_range = gnm_sheet_merge_is_corner (sheet, &pos);
 
 			if (od_cell_is_covered (sheet, current_cell, col, row,
 						merge_range, &sheet_merges)) {
@@ -449,7 +447,7 @@ oo_write_sheet (GnmOOExport *state, Sheet const *sheet)
 				continue;
 			}
 			if ((merge_range == NULL) && (cc == NULL) &&
-			    cell_is_empty (current_cell)) {
+			    gnm_cell_is_empty (current_cell)) {
 				if (covered_cell > 0)
 					od_write_covered_cell (state, &covered_cell);
 				null_cell++;
@@ -609,17 +607,13 @@ openoffice_file_save (GOFileSaver const *fs, IOContext *ioc,
 	};
 
 	GnmOOExport state;
-	char *old_num_locale, *old_monetary_locale;
 	GsfOutfile *outfile = NULL;
 	GsfOutput  *child;
+	GnmLocale  *locale;
 	GError *err;
 	unsigned i;
 
-	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
-	go_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
-	go_setlocale (LC_MONETARY, "C");
-	go_set_untranslated_bools ();
+	locale  = gnm_push_C_locale ();
 
 	outfile = gsf_outfile_zip_new (output, &err);
 
@@ -634,14 +628,10 @@ openoffice_file_save (GOFileSaver const *fs, IOContext *ioc,
 		g_object_unref (G_OBJECT (child));
 	}
 
+	g_free (state.conv);
+
 	gsf_output_close (GSF_OUTPUT (outfile));
 	g_object_unref (G_OBJECT (outfile));
 
-	/* go_setlocale restores bools to locale translation */
-	go_setlocale (LC_MONETARY, old_monetary_locale);
-	g_free (old_monetary_locale);
-	go_setlocale (LC_NUMERIC, old_num_locale);
-	g_free (old_num_locale);
-
-	g_free (state.conv);
+	gnm_pop_C_locale (locale);
 }
