@@ -13,7 +13,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include <goffice/app/file.h>
 #include <goffice/app/io-context.h>
@@ -29,13 +29,13 @@
 #include "style-color.h"
 #include "sheet-style.h"
 #include "number-match.h"
+#include "gutils.h"
 #include <goffice/app/error-info.h>
 #include <goffice/app/go-plugin.h>
 #include <gnm-plugin.h>
 
 #include <string.h>
 #include <errno.h>
-#include <locale.h>
 #include <stdlib.h>
 #include <gsf/gsf-input-stdio.h>
 #include <gsf/gsf-input-textline.h>
@@ -124,7 +124,7 @@ sylk_parse_value (SylkReadState *state, char const *str)
 	return value_new_string_nocopy (sylk_parse_string (str));
 }
 
-static GnmExpr *
+static GnmExprTop *
 sylk_parse_expr (SylkReadState *state, char const *str)
 {
 	g_print ("%s\n", str);
@@ -140,7 +140,7 @@ static gboolean
 sylk_rtd_c_parse (SylkReadState *state, char *str)
 {
 	GnmValue *val = NULL;
-	GnmExpr  *expr = NULL;
+	GnmExprTop const *texpr = NULL;
 	gboolean is_array = FALSE;
 	int r = -1, c = -1;
 	char *next;
@@ -161,22 +161,20 @@ sylk_rtd_c_parse (SylkReadState *state, char *str)
 			break;
 
 		case 'E':
-			if (expr != NULL) {
+			if (texpr != NULL) {
 				g_warning ("Multiple expressions");
-				gnm_expr_unref (expr);
-				expr = NULL;
+				gnm_expr_top_unref (texpr);
 			}
-			expr = sylk_parse_expr (state, str+1);
+			texpr = sylk_parse_expr (state, str+1);
 			break;
 		case 'M' : /* ;M exp: Expression stored with UL corner of matrix (;R ;C defines
 		  the lower right corner).  If the ;M field is supported, the
 		  ;K record is ignored.  Note that no ;E field is written. */
-			if (expr != NULL) {
+			if (texpr != NULL) {
 				g_warning ("Multiple expressions");
-				gnm_expr_unref (expr);
-				expr = NULL;
+				gnm_expr_top_unref (texpr);
 			}
-			expr = sylk_parse_expr (state, str+1);
+			texpr = sylk_parse_expr (state, str+1);
 			is_array = TRUE;
 			break;
 
@@ -218,26 +216,27 @@ sylk_rtd_c_parse (SylkReadState *state, char *str)
 		}
 	}
 
-	if (val != NULL || expr != NULL) {
+	if (val != NULL || texpr != NULL) {
 		GnmCell *cell = sheet_cell_fetch (state->sheet,
 			state->col - 1, state->row - 1);
 
 		if (val != NULL) {
-			GnmStyle *style = sheet_style_get (state->sheet,
+			GnmStyle const *style = sheet_style_get (state->sheet,
 				state->col - 1, state->row - 1);
 			value_set_fmt (val, gnm_style_get_format (style));
 		}
 
-		if (expr != NULL) {
+		if (texpr != NULL) {
 			if (val != NULL)
-				cell_set_expr_and_value (cell, expr, val, TRUE);
+				gnm_cell_set_expr_and_value
+					(cell, texpr, val, TRUE);
 			else
-				cell_set_expr (cell, expr);
-			gnm_expr_unref (expr);
+				gnm_cell_set_expr (cell, texpr);
+			gnm_expr_top_unref (texpr);
 		} else if (is_array)
-			cell_assign_value (cell, val);
+			gnm_cell_assign_value (cell, val);
 		else
-			cell_set_value (cell, val);
+			gnm_cell_set_value (cell, val);
 	}
 
 	return TRUE;
@@ -386,12 +385,14 @@ sylk_rtd_f_parse (SylkReadState *state, char *str)
 			break;
 		}
 		if (border != MSTYLE_ELEMENT_MAX) {
+			GnmStyleBorderLocation const loc =
+				GNM_STYLE_BORDER_TOP + (int)(border - MSTYLE_BORDER_TOP);
 			if (style == NULL)
 				style = gnm_style_new_default ();
 			gnm_style_set_border (style, border,
-				style_border_fetch (STYLE_BORDER_THIN,
+				gnm_style_border_fetch (GNM_STYLE_BORDER_THIN,
 					style_color_black (),
-					style_border_get_orientation (border - MSTYLE_BORDER_TOP)));
+					gnm_style_border_get_orientation (loc)));
 		}
 	}
 
@@ -488,9 +489,9 @@ sylk_file_open (GOFileOpener const *fo,
 	char const *input_name;
 	char *base;
 	int i;
-	Workbook *book = wb_view_workbook (wb_view);
+	GnmLocale *locale;
+	Workbook  *book = wb_view_get_workbook (wb_view);
 	ErrorInfo *sheet_error;
-	char *old_num_locale, *old_monetary_locale;
 
 	input_name = gsf_input_name (input);
 	if (input_name == NULL)
@@ -509,19 +510,11 @@ sylk_file_open (GOFileOpener const *fo,
 	workbook_sheet_attach (book, state.sheet);
 	g_free (base);
 
-	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
-	go_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
-	go_setlocale (LC_MONETARY, "C");
-	go_set_untranslated_bools ();
+	locale = gnm_push_C_locale ();
 
 	sylk_parse_sheet (&state, &sheet_error);
 
-	/* go_setlocale restores bools to locale translation */
-	go_setlocale (LC_MONETARY, old_monetary_locale);
-	g_free (old_monetary_locale);
-	go_setlocale (LC_NUMERIC, old_num_locale);
-	g_free (old_num_locale);
+	gnm_pop_C_locale (locale);
 
 	if (sheet_error != NULL)
 		gnumeric_io_error_info_set (io_context,
