@@ -127,7 +127,7 @@ ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 			   NULL);
 
 	i = gnumeric_glade_group_value (gui, error_group);
-	sr->error_behaviour = (i == -1) ? SRE_fail : (SearchReplaceError)i;
+	sr->error_behaviour = (i == -1) ? GNM_SRE_FAIL : (GnmSearchReplaceError)i;
 
 	err = gnm_search_replace_verify (sr, TRUE);
 	if (err) {
@@ -276,6 +276,9 @@ dialog_search_replace (WorkbookControlGUI *wbcg,
 	gtk_widget_show_all (dialog->vbox);
 	gtk_widget_grab_focus (GTK_WIDGET (dd->search_text));
 
+	gnm_dialog_setup_destroy_handlers (dialog, wbcg,
+					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
+
 	wbcg_edit_attach_guru (wbcg, GTK_WIDGET (dialog));
 	non_modal_dialog (wbcg, dialog, SEARCH_REPLACE_KEY);
 }
@@ -312,6 +315,9 @@ dialog_search_replace_query (WorkbookControlGUI *wbcg,
 	go_dialog_guess_alternative_button_order (dialog);
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 
+	gnm_dialog_setup_destroy_handlers (dialog, wbcg,
+					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
+
 	res = gtk_dialog_run (dialog);
 	switch (res) {
 	case GTK_RESPONSE_YES:
