@@ -208,7 +208,11 @@ update_log (SimulationState *state, simulation_t *sim)
 	}
 
 	path = gtk_tree_path_new_from_string ("0");
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path);
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path)) {
+		; 		/* Do something */
+	} else {
+		g_warning ("Did not get a valid iterator");
+	}
 	gtk_tree_path_free (path);
 
 	gtk_tree_view_append_column
@@ -445,6 +449,9 @@ dialog_simulation (WorkbookControlGUI *wbcg, G_GNUC_UNUSED Sheet *sheet)
 	gtk_widget_set_sensitive (w, FALSE);
 	gtk_widget_hide (w);
 
+	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog), wbcg,
+					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
+
 	gnm_dao_set_put (GNM_DAO (state->gdao), FALSE, FALSE);
 	simulation_update_sensitivity_cb (NULL, state);
 	tool_load_selection ((GenericToolState *)state, TRUE);
