@@ -856,8 +856,7 @@ cb_dialog_solve_clicked (G_GNUC_UNUSED GtkWidget *button,
 		return;
 	}
 
-	if (param->input_entry_str != NULL)
-		g_free (param->input_entry_str);
+	g_free (param->input_entry_str);
 	param->input_entry_str = value_get_as_string (input_range);
 
 	param->target_cell =
@@ -866,7 +865,7 @@ cb_dialog_solve_clicked (G_GNUC_UNUSED GtkWidget *button,
 				  target_range->v_range.cell.a.row );
 
 	/* Check that the target cell type is number. */
-	if (! cell_is_number (param->target_cell)) {
+	if (! gnm_cell_is_number (param->target_cell)) {
 		go_gtk_notice_nonmodal_dialog
 			((GtkWindow *) state->dialog,
 			 &(state->warning_dialog),
@@ -1354,6 +1353,9 @@ dialog_solver (WorkbookControlGUI *wbcg, Sheet *sheet)
 		return;
 	}
 
+	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog), wbcg,
+					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
+
 	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       SOLVER_KEY);
 
