@@ -56,14 +56,20 @@ functions_shutdown (void)
 	global_symbol_table = NULL;
 }
 
+inline void
+gnm_func_load_if_stub (GnmFunc *func)
+{
+	if (func->fn_type == GNM_FUNC_TYPE_STUB)
+		gnm_func_load_stub (func);	
+}
+
 static void
 copy_hash_table_to_ptr_array (gpointer key, gpointer value, gpointer array)
 {
 	Symbol *sym = value;
 	GnmFunc *fd = sym->data;
 	if (sym->type == SYMBOL_FUNCTION && fd->name != NULL) {
-		if (fd->fn_type == GNM_FUNC_TYPE_STUB)
-			gnm_func_load_stub ((GnmFunc *) fd);
+		gnm_func_load_if_stub ((GnmFunc *) fd);
 		if (fd->help != NULL)
 			g_ptr_array_add (array, fd);
 	}
@@ -121,8 +127,7 @@ cb_generate_po (gpointer key, Symbol *sym, gpointer array)
 	GnmFunc const *fd = sym->data;
 	char const *ptr, *tmp;
 
-	if (fd->fn_type == GNM_FUNC_TYPE_STUB)
-		gnm_func_load_stub ((GnmFunc *) fd);
+	gnm_func_load_if_stub ((GnmFunc *) fd);
 
 	if (fd->help == NULL) {
 		g_warning ("'%s' : no help defined", fd->name);
@@ -533,7 +538,7 @@ extract_arg_types (GnmFunc *def)
 }
 
 static GnmValue *
-error_function_no_full_info (FunctionEvalInfo *ei,
+error_function_no_full_info (GnmFuncEvalInfo *ei,
 			     int argc,
 			     GnmExprConstPtr const *argv)
 {
@@ -707,7 +712,7 @@ gnm_func_add (GnmFuncGroup *fn_group,
 
 /* Handle unknown functions on import without losing their names */
 static GnmValue *
-unknownFunctionHandler (FunctionEvalInfo *ei,
+unknownFunctionHandler (GnmFuncEvalInfo *ei,
 			int argc,
 			GnmExprConstPtr const *argv)
 {
@@ -853,8 +858,7 @@ function_def_count_args (GnmFunc const *fn_def,
 	g_return_if_fail (max != NULL);
 	g_return_if_fail (fn_def != NULL);
 
-	if (fn_def->fn_type == GNM_FUNC_TYPE_STUB)
-		gnm_func_load_stub ((GnmFunc *) fn_def);
+	gnm_func_load_if_stub ((GnmFunc *)fn_def);
 
 	/*
 	 * FIXME: clearly for 'nodes' functions many of
@@ -887,16 +891,14 @@ function_def_count_args (GnmFunc const *fn_def,
  * Return value: the type of the argument
  **/
 char
-function_def_get_arg_type (GnmFunc const *fn_def,
-                           int arg_idx)
+function_def_get_arg_type (GnmFunc const *fn_def, int arg_idx)
 {
 	char const *ptr;
 
 	g_return_val_if_fail (arg_idx >= 0, '?');
 	g_return_val_if_fail (fn_def != NULL, '?');
 
-	if (fn_def->fn_type == GNM_FUNC_TYPE_STUB)
-		gnm_func_load_stub ((GnmFunc *) fn_def);
+	gnm_func_load_if_stub ((GnmFunc *)fn_def);
 
 	switch (fn_def->fn_type) {
 	case GNM_FUNC_TYPE_ARGS:
@@ -963,41 +965,40 @@ function_def_get_arg_type_string (GnmFunc const *fn_def,
  *
  * Return value: the name of the argument (must be freed)
  **/
-char*
+char *
 function_def_get_arg_name (GnmFunc const *fn_def, int arg_idx)
 {
-	char **names, **o_names;
-	char *name;
+	const char *start, *end;
 	char *translated_arguments;
-	char delimiter[2];
+	gunichar uc;
+	char delimiter[7];
 
 	g_return_val_if_fail (arg_idx >= 0, NULL);
 	g_return_val_if_fail (fn_def != NULL, NULL);
 
-	if (fn_def->fn_type == GNM_FUNC_TYPE_STUB)
-		gnm_func_load_stub ((GnmFunc *) fn_def);
+	gnm_func_load_if_stub ((GnmFunc *)fn_def);
 
 	if (!fn_def->arg_names)
 		return NULL;
 
 	translated_arguments = _(fn_def->arg_names);
-	delimiter[0] =
-		strcmp (translated_arguments, fn_def->arg_names) == 0
+	uc = (strcmp (translated_arguments, fn_def->arg_names) == 0)
 		? ','
 		: format_get_arg_sep ();
-	delimiter[1] = 0;
-	names = g_strsplit (translated_arguments, delimiter, G_MAXINT);
-	o_names = names;
+	delimiter[g_unichar_to_utf8 (uc, delimiter)] = 0;
 
-	while (arg_idx-- && *names) {
-		names++;
+	start = translated_arguments;
+	while (arg_idx > 0) {
+		const char *del = strstr (start, delimiter);
+		if (!del)
+			return NULL;
+		arg_idx--;
+		start = del + strlen (delimiter);
 	}
+	end = strstr (start, delimiter);
+	if (!end) end = start + strlen (start);
 
-	if (*names == NULL)
-		return NULL;
-	name = g_strdup (*names);
-	g_strfreev (o_names);
-	return name;
+	return g_strndup (start, end - start);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -1013,9 +1014,8 @@ free_values (GnmValue **values, int top)
 }
 
 /**
- * function_call_with_list:
+ * function_call_with_exprs:
  * @ei: EvalInfo containing valid fn_def!
- * @args: GnmExprList of GnmExpr args.
  * @flags :
  *
  * Do the guts of calling a function.
@@ -1023,22 +1023,24 @@ free_values (GnmValue **values, int top)
  * Returns the result.
  **/
 GnmValue *
-function_call_with_exprs (FunctionEvalInfo *ei,
-			  int argc, GnmExprConstPtr const *argv,
-			  GnmExprEvalFlags flags)
+function_call_with_exprs (GnmFuncEvalInfo *ei, GnmExprEvalFlags flags)
 {
 	GnmFunc const *fn_def;
 	int	  i, iter_count, iter_width = 0, iter_height = 0;
 	char	  arg_type;
 	GnmValue	 **args, *tmp = NULL;
 	int 	 *iter_item = NULL;
+	int argc;
+	GnmExprConstPtr *argv;
 
 	g_return_val_if_fail (ei != NULL, NULL);
 	g_return_val_if_fail (ei->func_call != NULL, NULL);
 
+	argc = ei->func_call->argc;
+	argv = ei->func_call->argv;
 	fn_def = ei->func_call->func;
-	if (fn_def->fn_type == GNM_FUNC_TYPE_STUB)
-		gnm_func_load_stub ((GnmFunc *) fn_def);
+
+	gnm_func_load_if_stub ((GnmFunc *)fn_def);
 
 	/* Functions that deal with ExprNodes */
 	if (fn_def->fn_type == GNM_FUNC_TYPE_NODES)
@@ -1050,7 +1052,9 @@ function_call_with_exprs (FunctionEvalInfo *ei,
 		return value_new_error_NA (ei->pos);
 
 	args = g_alloca (sizeof (GnmValue *) * fn_def->fn.args.max_args);
-	iter_count = (ei->pos->array != NULL) ? 0 : -1;
+	iter_count = (ei->pos->array != NULL &&
+		      (flags & GNM_EXPR_EVAL_PERMIT_NON_SCALAR))
+		? 0 : -1;
 
 	for (i = 0; i < argc; i++) {
 		char arg_type = fn_def->fn.args.arg_types[i];
@@ -1063,8 +1067,6 @@ function_call_with_exprs (FunctionEvalInfo *ei,
 				GnmCellRef r;
 				gnm_cellref_make_abs (&r, &expr->cellref.ref, ei->pos);
 				args[i] = value_new_cellrange_unsafe (&r, &r);
-				/* TODO decide on the semantics of these argument types */
-#warning "Do we need to force an eval here?"
 			} else {
 				tmp = args[i] = gnm_expr_eval (expr, ei->pos,
 					GNM_EXPR_EVAL_PERMIT_NON_SCALAR);
@@ -1278,14 +1280,13 @@ function_def_call_with_values (GnmEvalPos const *ep, GnmFunc const *fn_def,
 {
 	GnmValue *retval;
 	GnmExprFunction	ef;
-	FunctionEvalInfo fs;
+	GnmFuncEvalInfo fs;
 
 	fs.pos = ep;
 	fs.func_call = &ef;
 	ef.func = (GnmFunc *)fn_def;
 
-	if (fn_def->fn_type == GNM_FUNC_TYPE_STUB)
-		gnm_func_load_stub (ef.func);
+	gnm_func_load_if_stub ((GnmFunc *)fn_def);
 
 	if (fn_def->fn_type == GNM_FUNC_TYPE_NODES) {
 		/*
@@ -1341,15 +1342,15 @@ cb_iterate_cellrange (GnmCellIter const *iter, gpointer user)
 		return (*data->callback)(&ep, NULL, data->closure);
 	}
 
-	if (data->ignore_subtotal && cell_has_expr (cell) &&
+	if (data->ignore_subtotal && gnm_cell_has_expr (cell) &&
 	    gnm_expr_top_contains_subtotal (cell->base.texpr))
 		return NULL;
 
-	cell_eval (cell);
+	gnm_cell_eval (cell);
 	eval_pos_init_cell (&ep, cell);
 
 	/* If we encounter an error for the strict case, short-circuit here.  */
-	if (data->strict && (NULL != (res = cell_is_error (cell))))
+	if (data->strict && (NULL != (res = gnm_cell_is_error (cell))))
 		return value_new_error_str (&ep, res->v_err.mesg);
 
 	/* All other cases -- including error -- just call the handler.  */
@@ -1523,8 +1524,7 @@ tokenized_help_new (GnmFunc const *func)
 
 	g_return_val_if_fail (func != NULL, NULL);
 
-	if (func->fn_type == GNM_FUNC_TYPE_STUB)
-		gnm_func_load_stub ((GnmFunc *) func);
+	gnm_func_load_if_stub ((GnmFunc *)func);
 
 	tok = g_new (TokenizedHelp, 1);
 	tok->fndef = func;
@@ -1603,8 +1603,7 @@ tokenized_help_destroy (TokenizedHelp *tok)
 {
 	g_return_if_fail (tok != NULL);
 
-	if (tok->help_copy)
-		g_free (tok->help_copy);
+	g_free (tok->help_copy);
 
 	if (tok->sections)
 		g_ptr_array_free (tok->sections, TRUE);
