@@ -2,14 +2,13 @@
 #define GUI_GNUMERIC_H
 
 #include "gnumeric.h"
-#include <libgnomecanvas/gnome-canvas.h>
 
 typedef struct _ItemCursor		ItemCursor;
 typedef struct _ItemGrid		ItemGrid;
 typedef struct _ItemBar			ItemBar;
 typedef struct _ItemEdit		ItemEdit;
-typedef struct _GnumericCanvas		GnumericCanvas;
-typedef struct _GnumericPane		GnumericPane;
+typedef struct _GnmCanvas		GnmCanvas;
+typedef struct _GnumericPane		GnmPane;
 typedef struct _SheetControlGUI		SheetControlGUI;
 typedef struct _WorkbookControlComponent  WorkbookControlComponent;
 typedef struct _WorkbookControlGUI	  WorkbookControlGUI;
