@@ -177,7 +177,7 @@ sheet_object_finalize (GObject *object)
 	SheetObject *so = SHEET_OBJECT (object);
 	if (so->sheet != NULL)
 		sheet_object_clear_sheet (so);
-	(*parent_klass->finalize) (object);
+	parent_klass->finalize (object);
 }
 
 static void
@@ -220,6 +220,7 @@ sheet_object_class_init (GObjectClass *klass)
 	sheet_object_class->print                = NULL;
 	sheet_object_class->user_config          = NULL;
 	sheet_object_class->rubber_band_directly = FALSE;
+	sheet_object_class->interactive          = FALSE;
 	sheet_object_class->default_size	 = so_default_size;
 	sheet_object_class->xml_export_name 	 = NULL;
 	sheet_object_class->invalidate_sheet     = NULL;
@@ -471,6 +472,7 @@ sheet_object_can_print (SheetObject const *so)
 		SO_CLASS (so)->print != NULL;
 }
 
+#ifdef WITH_GNOME_PRINT
 void
 sheet_object_print (SheetObject const *so, GnomePrintContext *ctx,
 		    double width, double height)
@@ -478,6 +480,7 @@ sheet_object_print (SheetObject const *so, GnomePrintContext *ctx,
 	if (SO_CLASS (so)->print)
 		SO_CLASS (so)->print (so, ctx, width, height);
 }
+#endif
 
 /**
  * sheet_object_draw_cairo :
@@ -1153,11 +1156,14 @@ void
 sheet_object_write_object (SheetObject const *so, char const *format,
 			  GsfOutput *output, GError **err)
 {
+	GnmLocale *locale;
+
 	g_return_if_fail (IS_SHEET_OBJECT_EXPORTABLE (so));
 
-	SHEET_OBJECT_EXPORTABLE_CLASS (so)->write_object (so, format, 
-							output, err);
-
+	locale = gnm_push_C_locale ();
+	SHEET_OBJECT_EXPORTABLE_CLASS (so)->write_object (so, format,
+							  output, err);
+	gnm_pop_C_locale (locale);
 }
 
 /*****************************************************************************/
