@@ -232,9 +232,9 @@ validation_eval (WorkbookControl *wbc, GnmStyle const *mstyle,
 
 	cell = sheet_cell_get (sheet, pos->col, pos->row);
 	if (cell != NULL)
-		cell_eval (cell);
+		gnm_cell_eval (cell);
 
-	if (cell_is_empty (cell)) {
+	if (gnm_cell_is_empty (cell)) {
 		if (v->allow_blank)
 			return VALIDATION_STATUS_VALID;
 		BARF (g_strdup_printf (_("Cell %s is not permitted to be blank"),
