@@ -25,7 +25,6 @@
 
 #include "libgnumeric.h"
 #include "application.h"
-#include "print.h"
 #include "commands.h"
 #include "clipboard.h"
 #include "selection.h"
@@ -51,7 +50,6 @@
 #include "workbook-view.h"
 #include "workbook-edit.h"
 #include "workbook-control-gui-priv.h"
-#include "workbook-control.h"
 #include "workbook-cmd-format.h"
 #include "dialogs/dialogs.h"
 #include "sheet-object-image.h"
@@ -64,6 +62,10 @@
 #include "gnumeric-gconf.h"
 #include "expr.h"
 
+#ifdef WITH_GNOME_PRINT
+#include "print.h"
+#endif
+
 #include <goffice/app/io-context.h>
 #include <goffice/graph/gog-guru.h>
 #include <goffice/graph/gog-data-allocator.h>
@@ -94,7 +96,12 @@ static GNM_ACTION_DEF (cb_file_save)	{ gui_file_save (wbcg, wb_control_view (WOR
 static GNM_ACTION_DEF (cb_file_save_as)	{ gui_file_save_as (wbcg, wb_control_view (WORKBOOK_CONTROL (wbcg))); }
 static GNM_ACTION_DEF (cb_file_sendto)	{
 	wb_view_sendto (wb_control_view (WORKBOOK_CONTROL (wbcg)), GO_CMD_CONTEXT (wbcg)); }
-static GNM_ACTION_DEF (cb_file_page_setup) { dialog_printer_setup (wbcg, wbcg_cur_sheet (wbcg)); }
+static GNM_ACTION_DEF (cb_file_page_setup)
+{ 
+#ifdef WITH_GNOME_PRINT
+	dialog_printer_setup (wbcg, wbcg_cur_sheet (wbcg));
+#endif
+}
 
 static GNM_ACTION_DEF (cb_file_print_area_set) {
 	Sheet *sheet = wbcg_cur_sheet (wbcg);
@@ -140,10 +147,20 @@ static GNM_ACTION_DEF (cb_file_print_area_show) {
 	sv_make_cell_visible (sv, r.start.col, r.start.row, FALSE);
 }
 
-static GNM_ACTION_DEF (cb_file_print)	{
-	sheet_print (wbcg, wbcg_cur_sheet (wbcg), FALSE, PRINT_ACTIVE_SHEET); }
-static GNM_ACTION_DEF (cb_file_print_preview) {
-	sheet_print (wbcg, wbcg_cur_sheet (wbcg), TRUE, PRINT_ACTIVE_SHEET); }
+static GNM_ACTION_DEF (cb_file_print)
+{
+#ifdef WITH_GNOME_PRINT
+	gnm_print_sheet (wbcg, wbcg_cur_sheet (wbcg), FALSE, PRINT_ACTIVE_SHEET);
+#endif
+}
+
+static GNM_ACTION_DEF (cb_file_print_preview)
+{
+#ifdef WITH_GNOME_PRINT
+	gnm_print_sheet (wbcg, wbcg_cur_sheet (wbcg), TRUE, PRINT_ACTIVE_SHEET);
+#endif
+}
+
 static GNM_ACTION_DEF (cb_doc_meta_data)	{ dialog_doc_metadata_new (wbcg); }
 static GNM_ACTION_DEF (cb_file_preferences)	{ dialog_preferences (wbcg, 0); }
 static GNM_ACTION_DEF (cb_file_close)		{ wbcg_close_control (wbcg); }
@@ -367,7 +384,7 @@ common_cell_goto (WorkbookControlGUI *wbcg, Sheet *sheet, GnmCellPos const *pos)
 }
 
 static int
-cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
+cb_edit_search_replace_query (GnmSearchReplaceQuery q, GnmSearchReplace *sr, ...)
 {
 	int res;
 	va_list pvar;
@@ -376,7 +393,7 @@ cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
 	va_start (pvar, sr);
 
 	switch (q) {
-	case SRQ_fail: {
+	case GNM_SRQ_FAIL: {
 		GnmCell *cell = va_arg (pvar, GnmCell *);
 		char const *old_text = va_arg (pvar, char const *);
 		char const *new_text = va_arg (pvar, char const *);
@@ -398,7 +415,7 @@ cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
 		break;
 	}
 
-	case SRQ_query: {
+	case GNM_SRQ_QUERY: {
 		GnmCell *cell = va_arg (pvar, GnmCell *);
 		char const *old_text = va_arg (pvar, char const *);
 		char const *new_text = va_arg (pvar, char const *);
@@ -414,7 +431,7 @@ cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
 		break;
 	}
 
-	case SRQ_querycommment: {
+	case GNM_SRQ_QUERY_COMMENT: {
 		Sheet *sheet = va_arg (pvar, Sheet *);
 		GnmCellPos *cp = va_arg (pvar, GnmCellPos *);
 		char const *old_text = va_arg (pvar, char const *);
@@ -473,7 +490,7 @@ static GNM_ACTION_DEF (cb_edit_fill_autofill)
 		/* trim is a bit overzealous, it forgets about merges */
 		do {
 			do_loop = FALSE;
-			merges = sheet_merge_get_overlap (sheet, &src);
+			merges = gnm_sheet_merge_get_overlap (sheet, &src);
 			for (ptr = merges ; ptr != NULL ; ptr = ptr->next) {
 				GnmRange const *r = ptr->data;
 				if (src.end.col < r->end.col) {
@@ -574,7 +591,7 @@ static GNM_ACTION_DEF (cb_view_freeze_panes)
 	SheetView *sv = wb_control_cur_sheet_view (wbc);
 	SheetControlGUI *scg = wbcg_cur_scg (wbcg);
 
-	scg_mode_edit (SHEET_CONTROL (scg));
+	scg_mode_edit (scg);
 	if (scg->active_panes == 1) {
 		gboolean center = FALSE;
 		GnmCanvas const *gcanvas = scg_pane (scg, 0);
@@ -778,7 +795,7 @@ static GNM_ACTION_DEF (cb_auto_filter)
 		 * filter the region below this row. */
 		region = *src;
 		if (src->start.row == src->end.row)
-			sheet_filter_guess_region  (sv->sheet, &region);
+			gnm_sheet_filter_guess_region  (sv->sheet, &region);
 		if (region.start.row == region.end.row) {
 			go_cmd_context_error_invalid	(GO_CMD_CONTEXT (wbcg),
 				 _("AutoFilter"), _("Requires more than 1 row"));
@@ -790,6 +807,9 @@ static GNM_ACTION_DEF (cb_auto_filter)
 		gnm_filter_remove (filter);
 		gnm_filter_free (filter);
 	}
+	/* ensure that the colour changes on the filtered row headers */
+	sheet_redraw_all (sv->sheet, TRUE);
+
 	sheet_mark_dirty (sv->sheet);
 	sheet_update (sv->sheet);
 }
@@ -1065,7 +1085,7 @@ create_object (WorkbookControlGUI *wbcg, GType t,
 	       ...)
 {
 	SheetControlGUI *scg = wbcg_cur_scg (wbcg);
-	Sheet *sheet = sc_sheet (SHEET_CONTROL (scg));
+	Sheet *sheet = scg_sheet (scg);
 	va_list	args;
 
 	va_start (args, first_property_name);
@@ -1330,14 +1350,14 @@ static GNM_ACTION_DEF (cb_format_as_date)
 static void
 mutate_borders (WorkbookControlGUI *wbcg, gboolean add)
 {
-	GnmBorder *borders [STYLE_BORDER_EDGE_MAX];
+	GnmBorder *borders [GNM_STYLE_BORDER_EDGE_MAX];
 	int i;
 
-	for (i = STYLE_BORDER_TOP; i < STYLE_BORDER_EDGE_MAX; ++i)
-		if (i <= STYLE_BORDER_RIGHT)
-			borders[i] = style_border_fetch (
-				add ? STYLE_BORDER_THIN : STYLE_BORDER_NONE,
-				style_color_black (), style_border_get_orientation (i));
+	for (i = GNM_STYLE_BORDER_TOP; i < GNM_STYLE_BORDER_EDGE_MAX; ++i)
+		if (i <= GNM_STYLE_BORDER_RIGHT)
+			borders[i] = gnm_style_border_fetch (
+				add ? GNM_STYLE_BORDER_THIN : GNM_STYLE_BORDER_NONE,
+				style_color_black (), gnm_style_border_get_orientation (i));
 		else
 			borders[i] = NULL;
 
@@ -1377,47 +1397,8 @@ static GNM_ACTION_DEF (cb_format_dec_precision)
 static GNM_ACTION_DEF (cb_format_with_thousands)
 	{ modify_format (wbcg, &go_format_toggle_1000sep, _("Toggle thousands separator")); }
 
-static GNM_ACTION_DEF (cb_format_inc_indent)
-{
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	WorkbookView const *wbv;
-	int i;
-
-	wbv = wb_control_view (wbc);
-	g_return_if_fail (wbv != NULL);
-	g_return_if_fail (wbv->current_format != NULL);
-
-	i = gnm_style_get_indent (wbv->current_format);
-	if (i < 20) {
-		GnmStyle *style = gnm_style_new ();
-
-		if (HALIGN_LEFT != gnm_style_get_align_h (wbv->current_format))
-			gnm_style_set_align_h (style, HALIGN_LEFT);
-		gnm_style_set_indent (style, i+1);
-		cmd_selection_format (wbc, style, NULL,
-			    _("Increase Indent"));
-	}
-}
-
-static GNM_ACTION_DEF (cb_format_dec_indent)
-{
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	WorkbookView const *wbv;
-	int i;
-
-	wbv = wb_control_view (wbc);
-	g_return_if_fail (wbv != NULL);
-	g_return_if_fail (wbv->current_format != NULL);
-
-	i = gnm_style_get_indent (wbv->current_format);
-	if (i > 0) {
-		GnmStyle *style = gnm_style_new ();
-
-		gnm_style_set_indent (style, i-1);
-		cmd_selection_format (wbc, style, NULL,
-			    _("Decrease Indent"));
-	}
-}
+static GNM_ACTION_DEF (cb_format_dec_indent) { workbook_cmd_dec_indent (WORKBOOK_CONTROL (wbcg)); }
+static GNM_ACTION_DEF (cb_format_inc_indent) { workbook_cmd_inc_indent (WORKBOOK_CONTROL (wbcg)); }
 
 static GNM_ACTION_DEF (cb_copydown)
 {
@@ -1966,10 +1947,10 @@ static GtkActionEntry const actions[] = {
 		NULL, N_("Uncollapse an outline group"),
 		G_CALLBACK (cb_data_show_detail) },
 	{ "DataOutlineGroup", "Gnumeric_Group", N_("_Group..."),
-		NULL, N_("Add an outline group"),
+		"<shift><alt>Right", N_("Add an outline group"),
 		G_CALLBACK (cb_data_group) },
 	{ "DataOutlineUngroup", "Gnumeric_Ungroup", N_("_Ungroup..."),
-		NULL, N_("Remove an outline group"),
+		"<shift><alt>Left", N_("Remove an outline group"),
 		G_CALLBACK (cb_data_ungroup) },
 
 /* Data -> Filter */
@@ -1989,7 +1970,7 @@ static GtkActionEntry const actions[] = {
 
 /* Standard Toolbar */
 	{ "AutoSum", "Gnumeric_AutoSum", N_("Sum"),
-		NULL, N_("Sum into the current cell"),
+		"<alt>equal", N_("Sum into the current cell"),
 		G_CALLBACK (cb_autosum) },
 	{ "InsertFormula", "Gnumeric_FormulaGuru", N_("Function"), NULL,
 		N_("Edit a function in the current cell"),
@@ -2094,11 +2075,14 @@ static GtkActionEntry const actions[] = {
 	{ "FormatDecreasePrecision", "Gnumeric_FormatRemovePrecision", N_("Decrease Precision"),
 		NULL, N_("Decrease the number of decimals displayed"),
 		G_CALLBACK (cb_format_dec_precision) },
+
+	/* Gtk marks these accelerators as invalid because they use Tab
+	 * enable them manually in gnumeric-canvas.c */
 	{ "FormatDecreaseIndent", GTK_STOCK_UNINDENT, NULL,
-		NULL, N_("Decrease the indent, and align the contents to the left"),
+		"<control><alt><shift>Tab", N_("Decrease the indent, and align the contents to the left"),
 		G_CALLBACK (cb_format_dec_indent) },
 	{ "FormatIncreaseIndent", GTK_STOCK_INDENT, NULL,
-		NULL, N_("Increase the indent, and align the contents to the left"),
+		"<control><alt>Tab", N_("Increase the indent, and align the contents to the left"),
 		G_CALLBACK (cb_format_inc_indent) },
 /* Unattached */
 #warning add descriptions for copy down/right
