@@ -46,13 +46,13 @@
 #include "workbook-cmd-format.h"
 #include "selection.h"
 #include "clipboard.h"
-#include "print.h"
 #include "gui-clipboard.h"
 #include "workbook-edit.h"
 #include "libgnumeric.h"
 #include "dependent.h"
 #include "expr.h"
 #include "expr-impl.h"
+#include "func.h"
 #include "position.h"
 #include "parse-util.h"
 #include "ranges.h"
@@ -77,6 +77,7 @@
 #include <goffice/graph/gog-data-set.h>
 #include <goffice/utils/go-file.h>
 #include <goffice/app/go-cmd-context-impl.h>
+#include <goffice/utils/go-glib-extras.h>
 
 #include <gsf/gsf-impl-utils.h>
 
@@ -86,6 +87,14 @@
 #include <string.h>
 #include <errno.h>
 
+enum {
+	PROP_0,
+	PROP_AUTOSAVE_PROMPT,
+	PROP_AUTOSAVE_TIME	
+};
+
+guint wbcg_signals[WBCG_LAST_SIGNAL];
+
 #define WBCG_CLASS(o) WORKBOOK_CONTROL_GUI_CLASS (G_OBJECT_GET_CLASS (o))
 #define WBCG_VIRTUAL_FULL(func, handle, arglist, call)		\
 void wbcg_ ## func arglist					\
@@ -147,14 +156,35 @@ static SheetControlGUI *
 wbcg_get_scg (WorkbookControlGUI *wbcg, Sheet *sheet)
 {
 	GtkWidget *w;
+	int i, npages;
 
 	if (sheet == NULL || wbcg->notebook == NULL)
 		return NULL;
 
 	g_return_val_if_fail (IS_SHEET (sheet), NULL);
+	g_return_val_if_fail (sheet->index_in_wb >= 0, NULL);
 
 	w = gtk_notebook_get_nth_page (wbcg->notebook, sheet->index_in_wb);
-	return g_object_get_data (G_OBJECT (w), SHEET_CONTROL_KEY);
+	if (w) {
+		SheetControlGUI *scg = g_object_get_data (G_OBJECT (w), SHEET_CONTROL_KEY);
+		if (scg_sheet (scg) == sheet)
+			return scg;
+	}
+
+	/*
+	 * index_in_wb is probably not accurate because we are in the
+	 * middle of removing or adding a sheet.
+	 */
+	npages = gtk_notebook_get_n_pages (wbcg->notebook);
+	for (i = 0; i < npages; i++) {
+		GtkWidget *w = gtk_notebook_get_nth_page (wbcg->notebook, i);
+		SheetControlGUI *scg = g_object_get_data (G_OBJECT (w), SHEET_CONTROL_KEY);
+		if (scg_sheet (scg) == sheet)
+			return scg;
+	}
+
+	g_warning ("Failed to find scg for sheet %s", sheet->name_quoted);
+	return NULL;
 }
 
 GtkWindow *
@@ -201,7 +231,7 @@ wbcg_focus_cur_scg (WorkbookControlGUI *wbcg)
 	g_return_val_if_fail (scg != NULL, NULL);
 
 	scg_take_focus (scg);
-	return sc_sheet (SHEET_CONTROL (scg));
+	return scg_sheet (scg);
 }
 
 Sheet *
@@ -218,11 +248,11 @@ wbcg_cur_scg (WorkbookControlGUI *wbcg)
 
 /****************************************************************************/
 /* Autosave */
+
 static gboolean
-cb_autosave (gpointer *data)
+cb_autosave (WorkbookControlGUI *wbcg)
 {
 	WorkbookView *wb_view;
-        WorkbookControlGUI *wbcg = (WorkbookControlGUI *)data;
 
 	g_return_val_if_fail (IS_WORKBOOK_CONTROL_GUI (wbcg), FALSE);
 
@@ -231,7 +261,7 @@ cb_autosave (gpointer *data)
 	if (wb_view == NULL)
 		return FALSE;
 
-	if (wbcg->autosave &&
+	if (wbcg->autosave_time > 0 &&
 	    go_doc_is_dirty (wb_view_get_doc (wb_view))) {
 	        if (wbcg->autosave_prompt && !dialog_autosave_prompt (wbcg))
 			return TRUE;
@@ -271,32 +301,39 @@ wbcg_is_editing (WorkbookControlGUI const *wbcg)
 	return wbcg->wb_control.editing;
 }
 
-void
+static void
 wbcg_autosave_cancel (WorkbookControlGUI *wbcg)
 {
-	g_return_if_fail (IS_WORKBOOK_CONTROL_GUI (wbcg));
-
 	if (wbcg->autosave_timer != 0) {
 		g_source_remove (wbcg->autosave_timer);
 		wbcg->autosave_timer = 0;
 	}
 }
 
-void
-wbcg_autosave_set (WorkbookControlGUI *wbcg, int minutes, gboolean prompt)
+static void
+wbcg_autosave_activate (WorkbookControlGUI *wbcg)
 {
-	g_return_if_fail (IS_WORKBOOK_CONTROL_GUI (wbcg));
+	wbcg_autosave_cancel (wbcg);	
 
-	wbcg_autosave_cancel (wbcg);
-
-	wbcg->autosave = (minutes != 0);
-	wbcg->autosave_minutes = minutes;
-	wbcg->autosave_prompt = prompt;
-
-	if (wbcg->autosave)
-		wbcg->autosave_timer = g_timeout_add (minutes * 60000,
-			(GSourceFunc) cb_autosave, wbcg);
+	if (wbcg->autosave_time > 0) {
+		int secs = MIN (wbcg->autosave_time, G_MAXINT / 1000);
+		wbcg->autosave_timer =
+			g_timeout_add (secs * 1000,
+				       (GSourceFunc) cb_autosave,
+				       wbcg);
+	}
 }
+
+static void
+wbcg_set_autosave_time (WorkbookControlGUI *wbcg, int secs)
+{
+	if (secs == wbcg->autosave_time)
+		return;
+
+	wbcg->autosave_time = secs;
+	wbcg_autosave_activate (wbcg);
+}
+
 /****************************************************************************/
 
 static void
@@ -493,7 +530,7 @@ sheet_menu_label_run (SheetControlGUI *scg, GdkEventButton *event)
 		gboolean inactive =
 			((flags & SHEET_CONTEXT_TEST_SIZE) &&
 			 workbook_sheet_count (sc->sheet->workbook) < 2) ||
-			wbcg_edit_get_guru (scg_get_wbcg (scg)) != NULL;
+			wbcg_edit_get_guru (scg_wbcg (scg)) != NULL;
 
 		if (text == NULL) {
 			item = gtk_separator_menu_item_new ();
@@ -525,7 +562,6 @@ cb_sheet_label_button_press (GtkWidget *widget, GdkEventButton *event,
 	GtkNotebook *notebook;
 	gint page_number;
 	GtkWidget *table = GTK_WIDGET (scg->table);
-
 	if (event->type != GDK_BUTTON_PRESS)
 		return FALSE;
 
@@ -537,7 +573,8 @@ cb_sheet_label_button_press (GtkWidget *widget, GdkEventButton *event,
 	if (event->button == 1 || NULL != scg->wbcg->rangesel)
 		return TRUE;
 
-	if (event->button == 3) {
+	if (event->button == 3 && 
+	    editable_label_get_editable (EDITABLE_LABEL (widget))) {
 		sheet_menu_label_run (scg, event);
 		scg_take_focus (scg);
 		return TRUE;
@@ -946,7 +983,7 @@ wbcg_sheet_add (WorkbookControl *wbc, SheetView *sv)
 	sc = (SheetControl *) scg;
 	for (ptr = sheet->sheet_objects; ptr != NULL ; ptr = ptr->next)
 		sc_object_create_view (sc, ptr->data);
-	scg_adjust_preferences (sc);
+	scg_adjust_preferences (scg);
 	if (sheet == wb_control_cur_sheet (wbc))
 		scg_take_focus (scg);
 }
@@ -972,27 +1009,31 @@ wbcg_sheet_focus (WorkbookControl *wbc, Sheet *sheet)
 	WorkbookControlGUI *wbcg = (WorkbookControlGUI *)wbc;
 	SheetControlGUI *scg = wbcg_get_scg (wbcg, sheet);
 
-	gtk_notebook_set_current_page (wbcg->notebook, sheet->index_in_wb);
+	if (sheet)
+		gtk_notebook_set_current_page (wbcg->notebook,
+					       sheet->index_in_wb);
 	if (wbcg->rangesel == NULL)
 		gnm_expr_entry_set_scg (wbcg->edit_line.entry, scg);
 
 	disconnect_sheet_signals (wbcg, wbcg_cur_sheet (wbcg), TRUE);
 
-	wbcg_update_menu_feedback (wbcg, sheet);
+	if (sheet) {
+		wbcg_update_menu_feedback (wbcg, sheet);
 
-	g_object_connect
-		(G_OBJECT (sheet),
-		 "signal::notify::display-formulas", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::display-zeros", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::display-grid", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::display-column-header", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::display-row-header", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::display-outlines", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::display-outlines-below", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::display-outlines-right", cb_toggle_menu_item_changed, wbcg,
-		 "signal::notify::text-is-rtl", cb_direction_change, scg,
-		 "signal::notify::zoom-factor", cb_zoom_change, wbcg,
-		 NULL);
+		g_object_connect
+			(G_OBJECT (sheet),
+			 "signal::notify::display-formulas", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::display-zeros", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::display-grid", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::display-column-header", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::display-row-header", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::display-outlines", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::display-outlines-below", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::display-outlines-right", cb_toggle_menu_item_changed, wbcg,
+			 "signal::notify::text-is-rtl", cb_direction_change, scg,
+			 "signal::notify::zoom-factor", cb_zoom_change, wbcg,
+			 NULL);
+	}
 }
 
 static void
@@ -1059,21 +1100,12 @@ wbcg_sheet_remove_all (WorkbookControl *wbc)
 }
 
 static void
-wbcg_auto_expr_value (WorkbookControl *wbc)
+wbcg_auto_expr_text_changed (WorkbookView *wbv,
+			     G_GNUC_UNUSED GParamSpec *pspec,
+			     WorkbookControlGUI *wbcg)
 {
-	WorkbookControlGUI *wbcg = WORKBOOK_CONTROL_GUI (wbc);
-	WorkbookView *wbv = wb_control_view (wbc);
-
-	g_return_if_fail (wbcg != NULL);
-	g_return_if_fail (wbv != NULL);
-	g_return_if_fail (wbv->auto_expr_value_as_string != NULL);
-
-	if (wbcg_ui_update_begin (wbcg)) {
-		gtk_label_set_text(
-			 GTK_LABEL (wbcg->auto_expr_label),
-			 wbv->auto_expr_value_as_string);
-		wbcg_ui_update_end (wbcg);
-	}
+	gtk_label_set_text (GTK_LABEL (wbcg->auto_expr_label),
+			    wbv->auto_expr_text ? wbv->auto_expr_text : "");
 }
 
 static void
@@ -1206,11 +1238,13 @@ wbcg_show_save_dialog (WorkbookControlGUI *wbcg,
 	int ret = 0;
 
 	if (wb_uri) {
-		char *base = go_basename_from_uri (wb_uri);
+		char *base    = go_basename_from_uri (wb_uri);
+		char *display = g_markup_escape_text (base, -1);
 		msg = g_strdup_printf (
 			_("Save changes to workbook '%s' before closing?"),
-			base);
+			display);
 		g_free (base);
+		g_free (display);
 	} else {
 		msg = g_strdup (_("Save changes to workbook before closing?"));
 	}
@@ -1380,6 +1414,8 @@ wbcg_close_control (WorkbookControlGUI *wbcg)
 	} else
 		g_object_unref (G_OBJECT (wbcg));
 
+	_gnm_app_flag_windows_changed ();
+
 	return FALSE;
 }
 
@@ -1400,8 +1436,19 @@ cb_editline_focus_in (GtkWidget *w, GdkEventFocus *event,
 		      WorkbookControlGUI *wbcg)
 {
 	if (!wbcg_is_editing (wbcg))
-		if (!wbcg_edit_start (wbcg, FALSE, TRUE))
+		if (!wbcg_edit_start (wbcg, FALSE, TRUE)) {
+			GtkEntry *entry = GTK_ENTRY (w);
 			wbcg_focus_cur_scg (wbcg);
+			entry->in_drag = FALSE;
+			/*
+			 * ->button is private, ugh.  Since the text area
+			 * never gets a release event, there seems to be
+			 * no official way of returning the widget to its
+			 * correct state.
+			 */
+			entry->button = 0;
+			return TRUE;
+		}
 
 	return FALSE;
 }
@@ -1573,6 +1620,45 @@ cb_notebook_switch_page (GtkNotebook *notebook, GtkNotebookPage *page,
 	}
 }
 
+static void
+wbcg_set_property (GObject *object, guint property_id,
+		   const GValue *value, GParamSpec *pspec)
+{
+	WorkbookControlGUI *wbcg = (WorkbookControlGUI *)object;
+
+	switch (property_id) {
+	case PROP_AUTOSAVE_PROMPT:
+		wbcg->autosave_prompt = g_value_get_boolean (value);
+		break;
+	case PROP_AUTOSAVE_TIME:
+		wbcg_set_autosave_time (wbcg, g_value_get_int (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+static void
+wbcg_get_property (GObject *object, guint property_id,
+		   GValue *value, GParamSpec *pspec)
+{
+	WorkbookControlGUI *wbcg = (WorkbookControlGUI *)object;
+
+	switch (property_id) {
+	case PROP_AUTOSAVE_PROMPT:
+		g_value_set_boolean (value, wbcg->autosave_prompt);
+		break;
+	case PROP_AUTOSAVE_TIME:
+		g_value_set_int (value, wbcg->autosave_time);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 static GObjectClass *parent_class;
 static void
 wbcg_finalize (GObject *obj)
@@ -1582,6 +1668,9 @@ wbcg_finalize (GObject *obj)
 	/* Disconnect signals that would attempt to change things during
 	 * destruction.
 	 */
+
+	wbcg_autosave_cancel (wbcg);
+
 	if (wbcg->notebook != NULL)
 		g_signal_handlers_disconnect_by_func (
 			G_OBJECT (wbcg->notebook),
@@ -1619,17 +1708,16 @@ wbcg_finalize (GObject *obj)
 	}
 #endif
 
-	(*parent_class->finalize) (obj);
+	parent_class->finalize (obj);
 }
 
-/* protected */
-gboolean
-wbcg_scroll_wheel_support_cb (GtkWidget *ignored, GdkEventScroll *event,
-			      WorkbookControlGUI *wbcg)
+static gboolean
+cb_scroll_wheel (GtkWidget *ignored, GdkEventScroll *event,
+		 WorkbookControlGUI *wbcg)
 {
 	/* scroll always operates on pane 0 */
 	SheetControlGUI *scg = wbcg_cur_scg (wbcg);
-	Sheet	 	*sheet = sc_sheet (SHEET_CONTROL (scg));
+	Sheet	 	*sheet = scg_sheet (scg);
 	GnmCanvas *gcanvas = scg_pane (scg, 0);
 	gboolean go_horiz = (event->direction == GDK_SCROLL_LEFT ||
 			     event->direction == GDK_SCROLL_RIGHT);
@@ -1859,13 +1947,20 @@ wbcg_get_font_desc (WorkbookControlGUI *wbcg)
 static void
 cb_auto_expr_changed (GtkWidget *item, WorkbookControlGUI *wbcg)
 {
+	const GnmFunc *func;
+	const char *descr;
+	WorkbookView *wbv = wb_control_view (WORKBOOK_CONTROL (wbcg));
+
 	if (wbcg->updating_ui)
 		return;
 
-	wb_view_auto_expr (
-		wb_control_view (WORKBOOK_CONTROL (wbcg)),
-		g_object_get_data (G_OBJECT (item), "name"),
-		g_object_get_data (G_OBJECT (item), "expr"));
+	func = g_object_get_data (G_OBJECT (item), "func");
+	descr = g_object_get_data (G_OBJECT (item), "descr");
+
+	g_object_set (wbv,
+		      "auto-expr-func", func,
+		      "auto-expr-descr", descr,
+		      NULL);
 }
 
 static void
@@ -1875,7 +1970,7 @@ cb_auto_expr_precision_toggled (GtkWidget *item, WorkbookControlGUI *wbcg)
 	if (wbcg->updating_ui)
 		return;
 
-	wb_view_auto_expr_precision (wbv, !wbv->auto_expr_use_max_precision);
+	go_object_toggle (wbv, "auto-expr-max-precision");
 }
 
 static gboolean
@@ -1930,8 +2025,10 @@ cb_select_auto_expr (GtkWidget *widget, GdkEventButton *event, WorkbookControlGU
 
 		item = gtk_menu_item_new_with_label (
 			_(quick_compute_routines [i].displayed_name));
-		g_object_set_data (G_OBJECT (item), "expr", (gpointer)expr);
-		g_object_set_data (G_OBJECT (item), "name",
+		g_object_set_data (G_OBJECT (item),
+				   "func",
+				   gnm_func_lookup (expr, NULL));
+		g_object_set_data (G_OBJECT (item), "descr",
 			(gpointer)_(quick_compute_routines [i].displayed_name));
 		g_signal_connect (G_OBJECT (item),
 			"activate",
@@ -2014,6 +2111,10 @@ show_gui (WorkbookControlGUI *wbcg)
 		if (requisition.height + 20 > rect.height || 
 		    requisition.width > rect.width) {
 			gtk_window_maximize (GTK_WINDOW (wbcg->toplevel));
+		} else {
+			gtk_window_set_default_size 
+				(wbcg_toplevel (wbcg), 
+				 requisition.width, requisition.height);
 		}
 	} else {
 		/* Use default */
@@ -2028,7 +2129,7 @@ show_gui (WorkbookControlGUI *wbcg)
 
 	/* rehide headers if necessary */
 	if (NULL != scg && wb_control_cur_sheet (WORKBOOK_CONTROL (wbcg)))
-		scg_adjust_preferences (SHEET_CONTROL (scg));
+		scg_adjust_preferences (scg);
 
 	return FALSE;
 }
@@ -2310,7 +2411,7 @@ wbcg_set_toplevel (WorkbookControlGUI *wbcg, GtkWidget *w)
 	g_signal_connect_after (w, "set_focus",
 		G_CALLBACK (cb_set_focus), wbcg);
 	g_signal_connect (w, "scroll-event",
-		G_CALLBACK (wbcg_scroll_wheel_support_cb), wbcg);
+		G_CALLBACK (cb_scroll_wheel), wbcg);
 	g_signal_connect (w, "realize",
 		G_CALLBACK (cb_realize), wbcg);
 
@@ -2397,35 +2498,47 @@ wbcg_progress_message_set (GOCmdContext *cc, gchar const *msg)
 	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (wbcg->progress_bar), msg);
 }
 
-#define DISCONNECT(field)						\
-	if (wbcg->field) {						\
-		g_signal_handler_disconnect (old_wb, wbcg->field);	\
-		wbcg->field = 0;					\
+#define DISCONNECT(obj,field)					\
+	if (wbcg->field) {					\
+		g_signal_handler_disconnect (obj, wbcg->field);	\
+		wbcg->field = 0;				\
 	}
 
 static void
 wbcg_view_changed (WorkbookControlGUI *wbcg,
 		   G_GNUC_UNUSED GParamSpec *pspec,
-		   Workbook *old_wb)
+		   WorkbookView *old_wbv)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	Workbook *wb = wb_control_get_workbook (wbc);
+	Workbook *old_wb = old_wbv ? wb_view_get_workbook (old_wbv) : NULL;
+	WorkbookView *wbv = wb_control_view (wbc);
 
 	/* Reconnect self because we need to change data.  */
-	if (wbcg->sig_view_changed)
-		g_signal_handler_disconnect (wbc, wbcg->sig_view_changed);
+	DISCONNECT (wbc, sig_view_changed);
 	wbcg->sig_view_changed =
 		g_signal_connect_object
 		(G_OBJECT (wbc),
 		 "notify::view",
 		 G_CALLBACK (wbcg_view_changed),
-		 wb,
+		 wbv,
 		 0);
 
+	if (wbcg->sig_auto_expr_text)
+		DISCONNECT (old_wbv, sig_auto_expr_text);
+	wbcg->sig_auto_expr_text =
+		g_signal_connect_object
+		(G_OBJECT (wbv),
+		 "notify::auto-expr-text",
+		 G_CALLBACK (wbcg_auto_expr_text_changed),
+		 wbcg,
+		 0);
+	wbcg_auto_expr_text_changed (wbv, NULL, wbcg);
+
 	if (old_wb) {
-		DISCONNECT (sig_sheet_order);
-		DISCONNECT (sig_notify_uri);
-		DISCONNECT (sig_notify_dirty);
+		DISCONNECT (old_wb, sig_sheet_order);
+		DISCONNECT (old_wb, sig_notify_uri);
+		DISCONNECT (old_wb, sig_notify_dirty);
 	}
 
 	if (wb) {
@@ -2466,7 +2579,7 @@ static void
 wbcg_data_allocator_allocate (GogDataAllocator *dalloc, GogPlot *plot)
 {
 	SheetControlGUI *scg = wbcg_cur_scg (WORKBOOK_CONTROL_GUI (dalloc));
-	sv_selection_to_plot (sc_view (SHEET_CONTROL (scg)), plot);
+	sv_selection_to_plot (scg_view (scg), plot);
 }
 
 typedef struct {
@@ -2492,7 +2605,7 @@ cb_graph_dim_editor_update (GnmExprEntry *gee,
 		return;
 
 	g_object_get (G_OBJECT (gee), "scg", &scg, NULL);
-	sheet = sc_sheet (SHEET_CONTROL (scg));
+	sheet = scg_sheet (scg);
 	g_object_unref (G_OBJECT (scg));
 
 	/* If we are setting something */
@@ -2517,7 +2630,7 @@ cb_graph_dim_editor_update (GnmExprEntry *gee,
 			else {
 				g_return_if_fail (perr.err != NULL);
 
-				wb_control_validation_msg (WORKBOOK_CONTROL (scg_get_wbcg (scg)),
+				wb_control_validation_msg (WORKBOOK_CONTROL (scg_wbcg (scg)),
 					VALIDATION_STYLE_PARSE_ERROR, NULL, perr.err->message);
 				parse_error_free (&perr);
 				return;
@@ -2620,7 +2733,6 @@ wbcg_go_plot_data_allocator_init (GogDataAllocatorClass *iface)
 
 /***************************************************************************/
 
-guint wbcg_signals [WBCG_LAST_SIGNAL];
 static void
 wbcg_gnm_cmd_context_init (GOCmdContextClass *iface)
 {
@@ -2633,21 +2745,41 @@ wbcg_gnm_cmd_context_init (GOCmdContextClass *iface)
 }
 
 static void
-workbook_control_gui_class_init (GObjectClass *object_class)
+workbook_control_gui_class_init (GObjectClass *gobject_class)
 {
 	WorkbookControlClass *wbc_class =
-		WORKBOOK_CONTROL_CLASS (object_class);
+		WORKBOOK_CONTROL_CLASS (gobject_class);
 	WorkbookControlGUIClass *wbcg_class =
-		WORKBOOK_CONTROL_GUI_CLASS (object_class);
+		WORKBOOK_CONTROL_GUI_CLASS (gobject_class);
 
 	g_return_if_fail (wbc_class != NULL);
 
-	parent_class = g_type_class_peek_parent (object_class);
-	object_class->finalize = wbcg_finalize;
+	parent_class = g_type_class_peek_parent (gobject_class);
+	gobject_class->finalize = wbcg_finalize;
+	gobject_class->get_property = wbcg_get_property;
+	gobject_class->set_property = wbcg_set_property;
+
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_AUTOSAVE_PROMPT,
+		 g_param_spec_boolean ("autosave-prompt",
+				       _("Autosave prompt"),
+				       _("Ask about autosave?"),
+				       FALSE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_AUTOSAVE_TIME,
+		 g_param_spec_int ("autosave-time",
+				   _("Autosave time in seconds"),
+				   _("Seconds before autosave"),
+				   0, G_MAXINT, 0,
+				   GSF_PARAM_STATIC |
+				   G_PARAM_READWRITE));
 
 	wbc_class->edit_line_set	= wbcg_edit_line_set;
 	wbc_class->selection_descr_set	= wbcg_edit_selection_descr_set;
-	wbc_class->auto_expr_value	= wbcg_auto_expr_value;
 	wbc_class->update_action_sensitivity = wbcg_update_action_sensitivity;
 
 	wbc_class->sheet.add        = wbcg_sheet_add;
@@ -2699,12 +2831,11 @@ workbook_control_gui_init (WorkbookControlGUI *wbcg)
 	wbcg->toggle_for_fullscreen = g_hash_table_new_full (
 		g_str_hash, g_str_equal, (GDestroyNotify)g_free, NULL);
 
-	/* Autosave */
-	wbcg->autosave_timer = 0;
-	wbcg->autosave_minutes = 0;
 	wbcg->autosave_prompt = FALSE;
+	wbcg->autosave_time = 0;
+	wbcg->autosave_timer = 0;
 
-#warning why is this here ?
+#warning "why is this here ?"
 	wbcg->current_saver = NULL;
 }
 
