@@ -25,9 +25,9 @@ struct _WorkbookView {
 	int preferred_width, preferred_height;
 
 	/* The auto-expression */
-	GnmExpr const *auto_expr;
-	char	  *auto_expr_desc;
-	char	  *auto_expr_value_as_string;
+	GnmFunc   *auto_expr_func;
+	char	  *auto_expr_descr;
+	char	  *auto_expr_text;
 	gboolean  auto_expr_use_max_precision;
 
 	/* selection */
@@ -52,6 +52,7 @@ GType		 workbook_view_get_type	  (void);
 WorkbookView	*workbook_view_new	  (Workbook *optional_workbook);
 void		 wb_view_attach_control	  (WorkbookView *wbv, WorkbookControl *wbc);
 void		 wb_view_detach_control	  (WorkbookControl *wbc);
+void             wb_view_detach_from_workbook (WorkbookView *wbv);
 
 /* Information */
 GODoc		*wb_view_get_doc	  (WorkbookView const *wbv);
@@ -68,18 +69,13 @@ void         	 wb_view_set_attribute	  (WorkbookView *wbv, char const *name,
 					   char const *value);
 void		 wb_view_preferred_size	  (WorkbookView *wbv,
 					   int w_pixels, int h_pixels);
-void		 wb_view_format_feedback  (WorkbookView *wbv, gboolean display);
+void		 wb_view_format_feedback  (WorkbookView *wbv);
 void             wb_view_menus_update     (WorkbookView *wbv);
 void		 wb_view_selection_desc   (WorkbookView *wbv, gboolean use_pos,
 					   WorkbookControl *optional_wbc);
 void		 wb_view_edit_line_set	  (WorkbookView *wbv,
 					   WorkbookControl *optional_wbc);
-void		 wb_view_auto_expr_recalc (WorkbookView *wbv, gboolean display);
-void		 wb_view_auto_expr	  (WorkbookView *wbv,
-					   char const *name,
-					   char const *func_name);
-void             wb_view_auto_expr_precision (WorkbookView *wbv,
-					      gboolean use_max_precision);
+void		 wb_view_auto_expr_recalc (WorkbookView *wbv);
 
 /* I/O routines */
 gboolean wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs,
