@@ -3,7 +3,7 @@
 /*
  * xml-sax-read.c : a sax based parser.  INCOMPLETE
  *
- * Copyright (C) 2000-2005 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -54,6 +54,7 @@
 #include "sheet-object-graph.h"
 #include "application.h"
 #include "xml-io.h"
+#include "gutils.h"
 
 #include <goffice/app/io-context.h>
 #include <goffice/app/go-plugin.h>
@@ -71,7 +72,6 @@
 #include <libxml/parserInternals.h>
 #include <stdlib.h>
 #include <string.h>
-#include <locale.h>
 
 GNM_PLUGIN_MODULE_HEADER;
 
@@ -386,9 +386,12 @@ xml_sax_wb_view (GsfXMLIn *gsf_state, xmlChar const **attrs)
 	int width = -1, height = -1;
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
-		if (xml_sax_attr_int (attrs, "SelectedTab", &sheet_index))
-			wb_view_sheet_focus (state->wb_view,
-				workbook_sheet_by_index (state->wb, sheet_index));
+		if (xml_sax_attr_int (attrs, "SelectedTab", &sheet_index)) {
+			Sheet *sheet = workbook_sheet_by_index (state->wb, 
+								sheet_index);
+			if (sheet)
+				wb_view_sheet_focus (state->wb_view, sheet);
+		} 
 		else if (xml_sax_attr_int (attrs, "Width", &width)) ;
 		else if (xml_sax_attr_int (attrs, "Height", &height)) ;
 		else
@@ -593,10 +596,12 @@ xml_sax_print_margins_unit (GsfXMLIn *gsf_state, xmlChar const **attrs, PrintUni
 {
 	double points;
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2) {
-		if (gnm_xml_attr_double (attrs, "Points", &points))
+		if (gnm_xml_attr_double (attrs, "Points", &points)) {
 			pu->points = points;
-		else if (!strcmp (attrs[0], "PrefUnit")) {
+#ifdef WITH_GNOME_PRINT
+		} else if (!strcmp (attrs[0], "PrefUnit")) {
 			pu->desired_display = unit_name_to_unit (attrs[1]);
+#endif
 		} else
 			unknown_attr (gsf_state, attrs);
 	}
@@ -1214,13 +1219,13 @@ xml_sax_style_region_borders (GsfXMLIn *gsf_state, xmlChar const **attrs)
 			unknown_attr (gsf_state, attrs);
 	}
 
-	if (pattern >= STYLE_BORDER_NONE) {
+	if (pattern >= GNM_STYLE_BORDER_NONE) {
 		GnmStyleElement const type = gsf_state->node->user_data.v_int;
-		StyleBorderLocation const loc =
-			STYLE_BORDER_TOP + (int)(type - MSTYLE_BORDER_TOP);
+		GnmStyleBorderLocation const loc =
+			GNM_STYLE_BORDER_TOP + (int)(type - MSTYLE_BORDER_TOP);
 		GnmBorder *border =
-			style_border_fetch ((StyleBorderType)pattern, colour,
-					    style_border_get_orientation (loc));
+			gnm_style_border_fetch ((GnmStyleBorderType)pattern, colour,
+					    gnm_style_border_get_orientation (loc));
 		gnm_style_set_border (state->style, type, border);
 	}
 }
@@ -1293,7 +1298,7 @@ xml_cell_set_array_expr (GnmCell *cell, char const *text,
 		parse_pos_init_cell (&pp, cell));
 
 	g_return_if_fail (texpr != NULL);
-	cell_set_array_formula (cell->base.sheet,
+	gnm_cell_set_array_formula (cell->base.sheet,
 				cell->pos.col, cell->pos.row,
 				cell->pos.col + cols-1, cell->pos.row + rows-1,
 				texpr);
@@ -1396,11 +1401,11 @@ xml_sax_cell_content (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 				if (v == NULL) {
 					g_warning ("Unable to parse \"%s\" as type %d.",
 						   content, value_type);
-					cell_set_text (cell, content);
+					gnm_cell_set_text (cell, content);
 				} else
-					cell_set_value (cell, v);
+					gnm_cell_set_value (cell, v);
 			} else
-				cell_set_text (cell, content);
+				gnm_cell_set_text (cell, content);
 		}
 
 		if (expr_id > 0) {
@@ -1408,7 +1413,7 @@ xml_sax_cell_content (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 			GnmExprTop const *texpr =
 				g_hash_table_lookup (state->expr_map, id);
 			if (texpr == NULL) {
-				if (cell_has_expr (cell))
+				if (gnm_cell_has_expr (cell))
 					g_hash_table_insert (state->expr_map, id,
 							     (gpointer)cell->base.texpr);
 				else
@@ -1421,7 +1426,7 @@ xml_sax_cell_content (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 			GINT_TO_POINTER (expr_id));
 
 		if (texpr != NULL)
-			cell_set_expr (cell, texpr);
+			gnm_cell_set_expr (cell, texpr);
 		else
 			g_warning ("XML-IO : Missing shared expression");
 	} else if (is_new_cell)
@@ -1430,7 +1435,7 @@ xml_sax_cell_content (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 		 * If it was created by a previous array
 		 * we do not want to erase it.
 		 */
-		cell_set_value (cell, value_new_empty ());
+		gnm_cell_set_value (cell, value_new_empty ());
 
 	if (value_fmt != NULL)
 		go_format_unref (value_fmt);
@@ -1445,7 +1450,7 @@ xml_sax_merge (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 	g_return_if_fail (gsf_state->content->len > 0);
 
 	if (range_parse (&r, gsf_state->content->str))
-		sheet_merge_add (state->sheet, &r, FALSE,
+		gnm_sheet_merge_add (state->sheet, &r, FALSE,
 			GO_CMD_CONTEXT (state->context));
 }
 
@@ -1588,13 +1593,13 @@ xml_sax_named_expr_end (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 
 	parse_error_free (&perr);
 
-	if (state->name.position) {
-		g_free (state->name.position);
-		state->name.position = NULL;
-	}
+	g_free (state->name.position);
+	state->name.position = NULL;
+
 	g_free (state->name.name);
-	g_free (state->name.value);
 	state->name.name = NULL;
+
+	g_free (state->name.value);
 	state->name.value = NULL;
 }
 
@@ -1918,7 +1923,7 @@ gnm_xml_file_open (GOFileOpener const *fo, IOContext *io_context,
 {
 	XMLSaxParseState state;
 	GsfXMLInDoc     *doc;
-	char *old_num_locale, *old_monetary_locale;
+	GnmLocale       *locale;
 
 	g_return_if_fail (IS_WORKBOOK_VIEW (wb_view));
 	g_return_if_fail (GSF_IS_INPUT (input));
@@ -1955,22 +1960,14 @@ gnm_xml_file_open (GOFileOpener const *fo, IOContext *io_context,
 	input = maybe_convert (input, FALSE);
 	gsf_input_seek (input, 0, G_SEEK_SET);
 
-	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
-	go_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
-	go_setlocale (LC_MONETARY, "C");
-	go_set_untranslated_bools ();
+	locale = gnm_push_C_locale ();
 
 	if (!gsf_xml_in_doc_parse (doc, input, &state))
 		gnumeric_io_error_string (io_context, _("XML document not well formed!"));
 	else
 		workbook_queue_all_recalc (state.wb);
 
-	/* go_setlocale restores bools to locale translation */
-	go_setlocale (LC_MONETARY, old_monetary_locale);
-	g_free (old_monetary_locale);
-	go_setlocale (LC_NUMERIC, old_num_locale);
-	g_free (old_num_locale);
+	gnm_pop_C_locale (locale);
 
 	g_object_unref (input);
 
