@@ -51,8 +51,8 @@
 #include <sheet-filter.h>
 #include <sheet-object-impl.h>
 #include <print-info.h>
-#include <print-info.h>
 #include <xml-io.h>
+#include <gutils.h>
 #include <clipboard.h>
 #include <tools/scenarios.h>
 #include <gnumeric-gconf.h>
@@ -63,7 +63,6 @@
 #include <gsf/gsf-doc-meta-data.h>
 #include <gsf/gsf-opendoc-utils.h>
 #include <gsf/gsf-utils.h>
-#include <locale.h>
 
 typedef struct {
 	WorkbookView const *wb_view;	/* View for the new workbook */
@@ -210,7 +209,9 @@ xml_write_print_unit (GnmOutputXML *state, char const *name,
 {
 	gsf_xml_out_start_element (state->output, name);
 	xml_out_add_points (state->output, "Points", pu->points);
+#ifdef WITH_GNOME_PRINT
 	gsf_xml_out_add_cstr_unchecked (state->output, "PrefUnit", pu->desired_display->abbr);
+#endif
 	gsf_xml_out_end_element (state->output);
 }
 
@@ -510,12 +511,12 @@ xml_write_gnmstyle (GnmOutputXML *state, GnmStyle const *style)
 			GnmBorder const *border;
 			if (gnm_style_is_element_set (style, i) &&
 			    NULL != (border = gnm_style_get_border (style, i))) {
-				StyleBorderType t = border->line_type;
+				GnmStyleBorderType t = border->line_type;
 				GnmColor *col   = border->color;
 				gsf_xml_out_start_element (state->output, 
 					border_names [i - MSTYLE_BORDER_TOP]);
 				gsf_xml_out_add_int (state->output, "Style", t);
-				if (t != STYLE_BORDER_NONE)
+				if (t != GNM_STYLE_BORDER_NONE)
 					gnm_xml_out_add_color (state->output, "Color", col);
 				gsf_xml_out_end_element (state->output);
 			}
@@ -667,8 +668,8 @@ xml_write_cell_and_position (GnmOutputXML *state,
 		return; /* DOM version would write <Cell Col= Row=/> */
 
 	gsf_xml_out_start_element (state->output, GNM "Cell");
-	gsf_xml_out_add_int (state->output, "Col", pp->eval.col);
 	gsf_xml_out_add_int (state->output, "Row", pp->eval.row);
+	gsf_xml_out_add_int (state->output, "Col", pp->eval.col);
 
 	/* As of version 0.53 we save the ID of shared expressions */
 	if (is_shared_expr) {
@@ -716,24 +717,21 @@ xml_write_cell_and_position (GnmOutputXML *state,
 	gsf_xml_out_end_element (state->output); /* </gnm:Cell> */
 }
 
-static void
-cb_write_cell (G_GNUC_UNUSED gpointer unused,
-	       GnmCell const *cell,
-	       GnmOutputXML *state)
+static GnmValue *
+cb_write_cell (GnmCellIter const *iter, GnmOutputXML *state)
 {
-	GnmParsePos pp;
-	parse_pos_init_cell (&pp, cell);
 	xml_write_cell_and_position (state,
-				     cell->base.texpr,
-				     cell->value,
-				     &pp);
+		iter->cell->base.texpr, iter->cell->value, &iter->pp);
+	return NULL;
 }
 
 static void
 xml_write_cells (GnmOutputXML *state)
 {
 	gsf_xml_out_start_element (state->output, GNM "Cells");
-	sheet_cell_foreach (state->sheet, (GHFunc)cb_write_cell, state);
+	sheet_foreach_cell_in_range ((Sheet *)state->sheet, CELL_ITER_IGNORE_NONEXISTENT,
+		0, 0, SHEET_MAX_COLS-1, SHEET_MAX_ROWS-1,
+		(CellIterFunc) cb_write_cell, state);
 	gsf_xml_out_end_element (state->output); /* </gnm:Cells> */
 }
 
@@ -1143,10 +1141,10 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 		   gconstpointer wb_view, GsfOutput *output)
 {
 	GnmOutputXML state;
-	char *old_num_locale, *old_monetary_locale;
-	char const *extension = NULL;
-	GsfOutput *gzout = NULL;
-	gboolean compress;
+	char const  *extension = NULL;
+	GsfOutput   *gzout = NULL;
+	GnmLocale   *locale;
+	gboolean     compress;
 
 	/* If the suffix is .xml disable compression */
 	if (NULL != gsf_output_name (output))
@@ -1168,11 +1166,7 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 	state.exprconv	= xml_io_conventions ();
 	state.expr_map  = g_hash_table_new (g_direct_hash, g_direct_equal);
 
-	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
-	go_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
-	go_setlocale (LC_MONETARY, "C");
-	go_set_untranslated_bools ();
+	locale = gnm_push_C_locale ();
 
 	gsf_xml_out_start_element (state.output, GNM "Workbook");
 	gsf_xml_out_add_cstr_unchecked (state.output, "xmlns:gnm",
@@ -1195,11 +1189,7 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 
 	gsf_xml_out_end_element (state.output); /* </Workbook> */
 
-	/* go_setlocale restores bools to locale translation */
-	go_setlocale (LC_MONETARY, old_monetary_locale);
-	g_free (old_monetary_locale);
-	go_setlocale (LC_NUMERIC, old_num_locale);
-	g_free (old_num_locale);
+	gnm_pop_C_locale (locale);
 
 	g_hash_table_destroy (state.expr_map);
 	gnm_expr_conventions_free (state.exprconv);
@@ -1213,6 +1203,22 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 
 /**************************************************************************/
 
+typedef struct {
+	GnmOutputXML  state;
+	GnmCellRegion const *cr;
+	GnmParsePos   pp;
+} XMLCellCopyState;
+
+static void
+cb_xml_write_cell_region_cells (GnmCellCopy *cc, gconstpointer ignore,
+				XMLCellCopyState *state)
+{
+	state->pp.eval.col = state->cr->base.col + cc->offset.col;
+	state->pp.eval.row = state->cr->base.row + cc->offset.row;
+	xml_write_cell_and_position (&state->state,
+		cc->texpr, cc->val, &state->pp);
+}
+
 /**
  * gnm_cellregion_to_xml :
  * @cr  : the content to store.
@@ -1224,84 +1230,72 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 GsfOutputMemory *
 gnm_cellregion_to_xml (GnmCellRegion const *cr)
 {
-	GnmOutputXML  state;
+	XMLCellCopyState state;
 	GnmStyleList *s_ptr;
-	GnmCellCopy const *cc;
 	GSList       *ptr;
-	GnmParsePos   pp;
-	char	     *old_num_locale, *old_monetary_locale;
 	GsfOutput    *buf = gsf_output_memory_new ();
+	GnmLocale    *locale;
 
 	g_return_val_if_fail (cr != NULL, NULL);
 	g_return_val_if_fail (IS_SHEET (cr->origin_sheet), NULL);
 
-	state.wb_view	= NULL;
-	state.wb	= NULL;
-	state.sheet	= NULL;
-	state.output	= gsf_xml_out_new (buf);
-	state.exprconv	= xml_io_conventions ();
-	state.expr_map  = g_hash_table_new (g_direct_hash, g_direct_equal);
+	state.state.wb_view	= NULL;
+	state.state.wb	= NULL;
+	state.state.sheet	= NULL;
+	state.state.output	= gsf_xml_out_new (buf);
+	state.state.exprconv	= xml_io_conventions ();
+	state.state.expr_map  = g_hash_table_new (g_direct_hash, g_direct_equal);
 
-	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
-	go_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
-	go_setlocale (LC_MONETARY, "C");
-	go_set_untranslated_bools ();
+	locale = gnm_push_C_locale ();
 
-	gsf_xml_out_start_element (state.output, GNM "ClipboardRange");
-	gsf_xml_out_add_cstr_unchecked (state.output, "xmlns:gnm",
+	gsf_xml_out_start_element (state.state.output, GNM "ClipboardRange");
+	gsf_xml_out_add_cstr_unchecked (state.state.output, "xmlns:gnm",
 		"http://www.gnumeric.org/v10.dtd");
 
-	gsf_xml_out_add_int (state.output, "Cols", cr->cols);
-	gsf_xml_out_add_int (state.output, "Rows", cr->rows);
-	gsf_xml_out_add_int (state.output, "BaseCol", cr->base.col);
-	gsf_xml_out_add_int (state.output, "BaseRow", cr->base.row);
+	gsf_xml_out_add_int (state.state.output, "Cols", cr->cols);
+	gsf_xml_out_add_int (state.state.output, "Rows", cr->rows);
+	gsf_xml_out_add_int (state.state.output, "BaseCol", cr->base.col);
+	gsf_xml_out_add_int (state.state.output, "BaseRow", cr->base.row);
 	if (cr->not_as_contents)
-		gsf_xml_out_add_bool (state.output, "NotAsContent", TRUE);
+		gsf_xml_out_add_bool (state.state.output, "NotAsContent", TRUE);
 
 	if (cr->styles != NULL) {
-		gsf_xml_out_start_element (state.output, GNM "Styles");
+		gsf_xml_out_start_element (state.state.output, GNM "Styles");
 		for (s_ptr = cr->styles ; s_ptr != NULL ; s_ptr = s_ptr->next)
-			xml_write_style_region (&state, s_ptr->data);
-		gsf_xml_out_end_element (state.output); /* </Styles> */
+			xml_write_style_region (&state.state, s_ptr->data);
+		gsf_xml_out_end_element (state.state.output); /* </Styles> */
 	}
 
 	if (cr->merged != NULL) {
-		gsf_xml_out_start_element (state.output, GNM "MergedRegions");
+		gsf_xml_out_start_element (state.state.output, GNM "MergedRegions");
 		for (ptr = cr->merged ; ptr != NULL ; ptr = ptr->next) {
-			gsf_xml_out_start_element (state.output, GNM "Merge");
-			gsf_xml_out_add_cstr_unchecked (state.output, NULL,
+			gsf_xml_out_start_element (state.state.output, GNM "Merge");
+			gsf_xml_out_add_cstr_unchecked (state.state.output, NULL,
 				range_as_string (ptr->data));
-			gsf_xml_out_end_element (state.output); /* </Merge> */
+			gsf_xml_out_end_element (state.state.output); /* </Merge> */
 		}
 	}
 
-	pp.wb = NULL; /* NOTE SNEAKY : ensure that sheet names have explicit workbooks */
-	pp.sheet = cr->origin_sheet;
-	if (cr->contents != NULL) {
-		gsf_xml_out_start_element (state.output, GNM "Cells");
-		for (ptr = cr->contents; ptr != NULL ; ptr = ptr->next) {
-			cc = ptr->data;
-			pp.eval.col = cr->base.col + cc->col_offset,
-			pp.eval.row = cr->base.row + cc->row_offset;
-			xml_write_cell_and_position (&state, cc->texpr, cc->val, &pp);
-		}
-		gsf_xml_out_end_element (state.output); /* </Cells> */
+	/* NOTE SNEAKY : ensure that sheet names have explicit workbooks */
+	state.pp.wb    = NULL;
+	state.pp.sheet = cr->origin_sheet;
+	state.cr = cr;
+	if (cr->cell_content != NULL) {
+		gsf_xml_out_start_element (state.state.output, GNM "Cells");
+		g_hash_table_foreach (cr->cell_content,
+			(GHFunc) cb_xml_write_cell_region_cells, &state);
+		gsf_xml_out_end_element (state.state.output); /* </Cells> */
 	}
 
-	xml_write_objects (&state, cr->objects);
+	xml_write_objects (&state.state, cr->objects);
 
-	gsf_xml_out_end_element (state.output); /* </ClipboardRange> */
+	gsf_xml_out_end_element (state.state.output); /* </ClipboardRange> */
 
-	/* go_setlocale restores bools to locale translation */
-	go_setlocale (LC_MONETARY, old_monetary_locale);
-	g_free (old_monetary_locale);
-	go_setlocale (LC_NUMERIC, old_num_locale);
-	g_free (old_num_locale);
+	gnm_pop_C_locale (locale);
 
-	g_hash_table_destroy (state.expr_map);
-	gnm_expr_conventions_free (state.exprconv);
-	g_object_unref (G_OBJECT (state.output));
+	g_hash_table_destroy (state.state.expr_map);
+	gnm_expr_conventions_free (state.state.exprconv);
+	g_object_unref (G_OBJECT (state.state.output));
 
 	gsf_output_close (buf);
 
